{-# LANGUAGE OverloadedStrings #-}
--
-- This module is autogenerated by 'make update-symbols', do not modify manually!
--
module Typst.Symbols (
  Sym(..),
  MathClass(..),
  typstSymbols,
  typstEmojis,
  mathSymbolShorthands
)
where

import Data.Text (Text)


-- | A record for a typst symbol.
data Sym = Sym{
  symName :: Text,
  symIsAccent :: Bool,
  symDeprecation :: Maybe Text,
  symMathClass :: MathClass,
  symText :: Text
  }
  deriving (Show)

-- | The math-class attribute for a typst symbol.
data MathClass =
    None
  | Alphabetic
  | Relation
  | Binary
  | Opening
  | Punctuation
  | Fence
  deriving (Show, Read)



-- | A list of triples, each consisting of the symbol name,
-- a Boolean indicating whether the symbol is an accent, and
-- the resolved symbol.
typstSymbols :: [Sym]
typstSymbols =

  [ Sym
      { symName = "AA"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\120120"
      }
  , Sym
      { symName = "Alpha"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\913"
      }
  , Sym
      { symName = "BB"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\120121"
      }
  , Sym
      { symName = "Beta"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\914"
      }
  , Sym
      { symName = "CC"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\8450"
      }
  , Sym
      { symName = "Chi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\935"
      }
  , Sym
      { symName = "DD"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\120123"
      }
  , Sym
      { symName = "Delta"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\916"
      }
  , Sym
      { symName = "Digamma"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\988"
      }
  , Sym
      { symName = "EE"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\120124"
      }
  , Sym
      { symName = "Epsilon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\917"
      }
  , Sym
      { symName = "Eta"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\919"
      }
  , Sym
      { symName = "FF"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\120125"
      }
  , Sym
      { symName = "GG"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\120126"
      }
  , Sym
      { symName = "Gamma"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\915"
      }
  , Sym
      { symName = "HH"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\8461"
      }
  , Sym
      { symName = "II"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\120128"
      }
  , Sym
      { symName = "Im"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\8465"
      }
  , Sym
      { symName = "Iota"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\921"
      }
  , Sym
      { symName = "JJ"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\120129"
      }
  , Sym
      { symName = "KK"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\120130"
      }
  , Sym
      { symName = "Kappa"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\922"
      }
  , Sym
      { symName = "LL"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\120131"
      }
  , Sym
      { symName = "Lambda"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\923"
      }
  , Sym
      { symName = "MM"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\120132"
      }
  , Sym
      { symName = "Mu"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\924"
      }
  , Sym
      { symName = "NN"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\8469"
      }
  , Sym
      { symName = "Nu"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\925"
      }
  , Sym
      { symName = "OO"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\120134"
      }
  , Sym
      { symName = "Omega"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\937"
      }
  , Sym
      { symName = "Omega.inv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8487"
      }
  , Sym
      { symName = "Omicron"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\927"
      }
  , Sym
      { symName = "PP"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\8473"
      }
  , Sym
      { symName = "Phi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\934"
      }
  , Sym
      { symName = "Pi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\928"
      }
  , Sym
      { symName = "Psi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\936"
      }
  , Sym
      { symName = "QQ"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\8474"
      }
  , Sym
      { symName = "RR"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\8477"
      }
  , Sym
      { symName = "Re"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\8476"
      }
  , Sym
      { symName = "Rho"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\929"
      }
  , Sym
      { symName = "SS"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\120138"
      }
  , Sym
      { symName = "Sha"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\1064"
      }
  , Sym
      { symName = "Sigma"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\931"
      }
  , Sym
      { symName = "TT"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\120139"
      }
  , Sym
      { symName = "Tau"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\932"
      }
  , Sym
      { symName = "Theta"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\920"
      }
  , Sym
      { symName = "Theta.alt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\1012"
      }
  , Sym
      { symName = "UU"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\120140"
      }
  , Sym
      { symName = "Upsilon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\933"
      }
  , Sym
      { symName = "VV"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\120141"
      }
  , Sym
      { symName = "WW"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\120142"
      }
  , Sym
      { symName = "XX"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\120143"
      }
  , Sym
      { symName = "Xi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\926"
      }
  , Sym
      { symName = "YY"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\120144"
      }
  , Sym
      { symName = "ZZ"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\8484"
      }
  , Sym
      { symName = "Zeta"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\918"
      }
  , Sym
      { symName = "acute"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\180"
      }
  , Sym
      { symName = "acute.double"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\733"
      }
  , Sym
      { symName = "afghani"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\1547"
      }
  , Sym
      { symName = "aleph"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\1488"
      }
  , Sym
      { symName = "alpha"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\945"
      }
  , Sym
      { symName = "amp"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "&"
      }
  , Sym
      { symName = "amp.inv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8523"
      }
  , Sym
      { symName = "and"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8743"
      }
  , Sym
      { symName = "and.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8896"
      }
  , Sym
      { symName = "and.curly"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8911"
      }
  , Sym
      { symName = "and.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10193"
      }
  , Sym
      { symName = "and.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10835"
      }
  , Sym
      { symName = "angle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8736"
      }
  , Sym
      { symName = "angle.acute"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10655"
      }
  , Sym
      { symName = "angle.arc"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8737"
      }
  , Sym
      { symName = "angle.arc.rev"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10651"
      }
  , Sym
      { symName = "angle.azimuth"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\9084"
      }
  , Sym
      { symName = "angle.obtuse"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10662"
      }
  , Sym
      { symName = "angle.rev"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10659"
      }
  , Sym
      { symName = "angle.right"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8735"
      }
  , Sym
      { symName = "angle.right.rev"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11262"
      }
  , Sym
      { symName = "angle.right.arc"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8894"
      }
  , Sym
      { symName = "angle.right.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10653"
      }
  , Sym
      { symName = "angle.right.square"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10652"
      }
  , Sym
      { symName = "angle.s"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10654"
      }
  , Sym
      { symName = "angle.spatial"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10176"
      }
  , Sym
      { symName = "angle.spheric"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8738"
      }
  , Sym
      { symName = "angle.spheric.rev"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10656"
      }
  , Sym
      { symName = "angle.spheric.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10657"
      }
  , Sym
      { symName = "angstrom"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\197"
      }
  , Sym
      { symName = "angzarr"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\9084"
      }
  , Sym
      { symName = "approx"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8776"
      }
  , Sym
      { symName = "approx.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8778"
      }
  , Sym
      { symName = "approx.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8777"
      }
  , Sym
      { symName = "approx.hat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10863"
      }
  , Sym
      { symName = "arrow.r"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8594"
      }
  , Sym
      { symName = "arrow.r.long.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10236"
      }
  , Sym
      { symName = "arrow.r.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8614"
      }
  , Sym
      { symName = "arrow.r.curve"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10551"
      }
  , Sym
      { symName = "arrow.r.turn"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11150"
      }
  , Sym
      { symName = "arrow.r.dashed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8674"
      }
  , Sym
      { symName = "arrow.r.dotted"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10513"
      }
  , Sym
      { symName = "arrow.r.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8658"
      }
  , Sym
      { symName = "arrow.r.double.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10503"
      }
  , Sym
      { symName = "arrow.r.double.long"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10233"
      }
  , Sym
      { symName = "arrow.r.double.long.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10238"
      }
  , Sym
      { symName = "arrow.r.double.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8655"
      }
  , Sym
      { symName = "arrow.r.double.struck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10499"
      }
  , Sym
      { symName = "arrow.r.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10145"
      }
  , Sym
      { symName = "arrow.r.hook"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8618"
      }
  , Sym
      { symName = "arrow.r.long"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10230"
      }
  , Sym
      { symName = "arrow.r.long.squiggly"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10239"
      }
  , Sym
      { symName = "arrow.r.loop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8620"
      }
  , Sym
      { symName = "arrow.r.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8603"
      }
  , Sym
      { symName = "arrow.r.quad"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11078"
      }
  , Sym
      { symName = "arrow.r.squiggly"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8669"
      }
  , Sym
      { symName = "arrow.r.stop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8677"
      }
  , Sym
      { symName = "arrow.r.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8680"
      }
  , Sym
      { symName = "arrow.r.struck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8696"
      }
  , Sym
      { symName = "arrow.r.dstruck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8699"
      }
  , Sym
      { symName = "arrow.r.tail"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8611"
      }
  , Sym
      { symName = "arrow.r.tail.struck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10516"
      }
  , Sym
      { symName = "arrow.r.tail.dstruck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10517"
      }
  , Sym
      { symName = "arrow.r.tilde"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10610"
      }
  , Sym
      { symName = "arrow.r.triple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8667"
      }
  , Sym
      { symName = "arrow.r.twohead"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8608"
      }
  , Sym
      { symName = "arrow.r.twohead.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10501"
      }
  , Sym
      { symName = "arrow.r.twohead.struck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10496"
      }
  , Sym
      { symName = "arrow.r.twohead.dstruck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10497"
      }
  , Sym
      { symName = "arrow.r.twohead.tail"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10518"
      }
  , Sym
      { symName = "arrow.r.twohead.tail.struck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10519"
      }
  , Sym
      { symName = "arrow.r.twohead.tail.dstruck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10520"
      }
  , Sym
      { symName = "arrow.r.open"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8702"
      }
  , Sym
      { symName = "arrow.r.wave"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8605"
      }
  , Sym
      { symName = "arrow.l"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8592"
      }
  , Sym
      { symName = "arrow.l.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8612"
      }
  , Sym
      { symName = "arrow.l.curve"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10550"
      }
  , Sym
      { symName = "arrow.l.turn"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11148"
      }
  , Sym
      { symName = "arrow.l.dashed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8672"
      }
  , Sym
      { symName = "arrow.l.dotted"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11064"
      }
  , Sym
      { symName = "arrow.l.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8656"
      }
  , Sym
      { symName = "arrow.l.double.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10502"
      }
  , Sym
      { symName = "arrow.l.double.long"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10232"
      }
  , Sym
      { symName = "arrow.l.double.long.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10237"
      }
  , Sym
      { symName = "arrow.l.double.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8653"
      }
  , Sym
      { symName = "arrow.l.double.struck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10498"
      }
  , Sym
      { symName = "arrow.l.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11013"
      }
  , Sym
      { symName = "arrow.l.hook"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8617"
      }
  , Sym
      { symName = "arrow.l.long"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10229"
      }
  , Sym
      { symName = "arrow.l.long.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10235"
      }
  , Sym
      { symName = "arrow.l.long.squiggly"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11059"
      }
  , Sym
      { symName = "arrow.l.loop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8619"
      }
  , Sym
      { symName = "arrow.l.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8602"
      }
  , Sym
      { symName = "arrow.l.quad"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11077"
      }
  , Sym
      { symName = "arrow.l.squiggly"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8668"
      }
  , Sym
      { symName = "arrow.l.stop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8676"
      }
  , Sym
      { symName = "arrow.l.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8678"
      }
  , Sym
      { symName = "arrow.l.struck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8695"
      }
  , Sym
      { symName = "arrow.l.dstruck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8698"
      }
  , Sym
      { symName = "arrow.l.tail"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8610"
      }
  , Sym
      { symName = "arrow.l.tail.struck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11065"
      }
  , Sym
      { symName = "arrow.l.tail.dstruck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11066"
      }
  , Sym
      { symName = "arrow.l.tilde"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11081"
      }
  , Sym
      { symName = "arrow.l.triple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8666"
      }
  , Sym
      { symName = "arrow.l.twohead"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8606"
      }
  , Sym
      { symName = "arrow.l.twohead.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11062"
      }
  , Sym
      { symName = "arrow.l.twohead.struck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11060"
      }
  , Sym
      { symName = "arrow.l.twohead.dstruck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11061"
      }
  , Sym
      { symName = "arrow.l.twohead.tail"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11067"
      }
  , Sym
      { symName = "arrow.l.twohead.tail.struck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11068"
      }
  , Sym
      { symName = "arrow.l.twohead.tail.dstruck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11069"
      }
  , Sym
      { symName = "arrow.l.open"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8701"
      }
  , Sym
      { symName = "arrow.l.wave"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8604"
      }
  , Sym
      { symName = "arrow.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8593"
      }
  , Sym
      { symName = "arrow.t.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8613"
      }
  , Sym
      { symName = "arrow.t.curve"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10548"
      }
  , Sym
      { symName = "arrow.t.turn"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11149"
      }
  , Sym
      { symName = "arrow.t.dashed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8673"
      }
  , Sym
      { symName = "arrow.t.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8657"
      }
  , Sym
      { symName = "arrow.t.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11014"
      }
  , Sym
      { symName = "arrow.t.quad"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10224"
      }
  , Sym
      { symName = "arrow.t.stop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10514"
      }
  , Sym
      { symName = "arrow.t.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8679"
      }
  , Sym
      { symName = "arrow.t.struck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10505"
      }
  , Sym
      { symName = "arrow.t.dstruck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8670"
      }
  , Sym
      { symName = "arrow.t.triple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10506"
      }
  , Sym
      { symName = "arrow.t.twohead"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8607"
      }
  , Sym
      { symName = "arrow.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8595"
      }
  , Sym
      { symName = "arrow.b.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8615"
      }
  , Sym
      { symName = "arrow.b.curve"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10549"
      }
  , Sym
      { symName = "arrow.b.turn"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11151"
      }
  , Sym
      { symName = "arrow.b.dashed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8675"
      }
  , Sym
      { symName = "arrow.b.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8659"
      }
  , Sym
      { symName = "arrow.b.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11015"
      }
  , Sym
      { symName = "arrow.b.quad"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10225"
      }
  , Sym
      { symName = "arrow.b.stop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10515"
      }
  , Sym
      { symName = "arrow.b.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8681"
      }
  , Sym
      { symName = "arrow.b.struck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10504"
      }
  , Sym
      { symName = "arrow.b.dstruck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8671"
      }
  , Sym
      { symName = "arrow.b.triple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10507"
      }
  , Sym
      { symName = "arrow.b.twohead"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8609"
      }
  , Sym
      { symName = "arrow.l.r"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8596"
      }
  , Sym
      { symName = "arrow.l.r.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8660"
      }
  , Sym
      { symName = "arrow.l.r.double.long"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10234"
      }
  , Sym
      { symName = "arrow.l.r.double.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8654"
      }
  , Sym
      { symName = "arrow.l.r.double.struck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10500"
      }
  , Sym
      { symName = "arrow.l.r.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11020"
      }
  , Sym
      { symName = "arrow.l.r.long"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10231"
      }
  , Sym
      { symName = "arrow.l.r.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8622"
      }
  , Sym
      { symName = "arrow.l.r.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11012"
      }
  , Sym
      { symName = "arrow.l.r.struck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8697"
      }
  , Sym
      { symName = "arrow.l.r.dstruck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8700"
      }
  , Sym
      { symName = "arrow.l.r.open"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8703"
      }
  , Sym
      { symName = "arrow.l.r.wave"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8621"
      }
  , Sym
      { symName = "arrow.t.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8597"
      }
  , Sym
      { symName = "arrow.t.b.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8661"
      }
  , Sym
      { symName = "arrow.t.b.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11021"
      }
  , Sym
      { symName = "arrow.t.b.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8691"
      }
  , Sym
      { symName = "arrow.tr"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8599"
      }
  , Sym
      { symName = "arrow.tr.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129209"
      }
  , Sym
      { symName = "arrow.tr.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8663"
      }
  , Sym
      { symName = "arrow.tr.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11016"
      }
  , Sym
      { symName = "arrow.tr.hook"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10532"
      }
  , Sym
      { symName = "arrow.tr.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11008"
      }
  , Sym
      { symName = "arrow.br"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8600"
      }
  , Sym
      { symName = "arrow.br.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129210"
      }
  , Sym
      { symName = "arrow.br.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8664"
      }
  , Sym
      { symName = "arrow.br.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11018"
      }
  , Sym
      { symName = "arrow.br.hook"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10533"
      }
  , Sym
      { symName = "arrow.br.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11010"
      }
  , Sym
      { symName = "arrow.tl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8598"
      }
  , Sym
      { symName = "arrow.tl.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129208"
      }
  , Sym
      { symName = "arrow.tl.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8662"
      }
  , Sym
      { symName = "arrow.tl.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11017"
      }
  , Sym
      { symName = "arrow.tl.hook"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10531"
      }
  , Sym
      { symName = "arrow.tl.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11009"
      }
  , Sym
      { symName = "arrow.bl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8601"
      }
  , Sym
      { symName = "arrow.bl.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129211"
      }
  , Sym
      { symName = "arrow.bl.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8665"
      }
  , Sym
      { symName = "arrow.bl.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11019"
      }
  , Sym
      { symName = "arrow.bl.hook"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10534"
      }
  , Sym
      { symName = "arrow.bl.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11011"
      }
  , Sym
      { symName = "arrow.tl.br"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10529"
      }
  , Sym
      { symName = "arrow.tr.bl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10530"
      }
  , Sym
      { symName = "arrow.ccw"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8634"
      }
  , Sym
      { symName = "arrow.ccw.half"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8630"
      }
  , Sym
      { symName = "arrow.cw"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8635"
      }
  , Sym
      { symName = "arrow.cw.half"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8631"
      }
  , Sym
      { symName = "arrow.zigzag"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8623"
      }
  , Sym
      { symName = "arrowhead.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8963"
      }
  , Sym
      { symName = "arrowhead.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8964"
      }
  , Sym
      { symName = "arrows.rr"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8649"
      }
  , Sym
      { symName = "arrows.ll"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8647"
      }
  , Sym
      { symName = "arrows.tt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8648"
      }
  , Sym
      { symName = "arrows.bb"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8650"
      }
  , Sym
      { symName = "arrows.lr"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8646"
      }
  , Sym
      { symName = "arrows.lr.stop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8633"
      }
  , Sym
      { symName = "arrows.rl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8644"
      }
  , Sym
      { symName = "arrows.rl.long"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129232"
      }
  , Sym
      { symName = "arrows.tb"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8645"
      }
  , Sym
      { symName = "arrows.bt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8693"
      }
  , Sym
      { symName = "arrows.rrr"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8694"
      }
  , Sym
      { symName = "arrows.lll"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11057"
      }
  , Sym
      { symName = "ast.op"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8727"
      }
  , Sym
      { symName = "ast.op.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8859"
      }
  , Sym
      { symName = "ast.basic"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "*"
      }
  , Sym
      { symName = "ast.low"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8270"
      }
  , Sym
      { symName = "ast.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8273"
      }
  , Sym
      { symName = "ast.triple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8258"
      }
  , Sym
      { symName = "ast.square"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10694"
      }
  , Sym
      { symName = "asymp"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8781"
      }
  , Sym
      { symName = "asymp.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8813"
      }
  , Sym
      { symName = "at"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "@"
      }
  , Sym
      { symName = "backslash"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\\"
      }
  , Sym
      { symName = "backslash.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10680"
      }
  , Sym
      { symName = "backslash.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10743"
      }
  , Sym
      { symName = "bag.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\10181"
      }
  , Sym
      { symName = "bag.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10182"
      }
  , Sym
      { symName = "baht"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\3647"
      }
  , Sym
      { symName = "ballot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9744"
      }
  , Sym
      { symName = "ballot.cross"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9746"
      }
  , Sym
      { symName = "ballot.check"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9745"
      }
  , Sym
      { symName = "ballot.check.heavy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128505"
      }
  , Sym
      { symName = "bar.v"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Fence
      , symText = "|"
      }
  , Sym
      { symName = "bar.v.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Fence
      , symText = "\8214"
      }
  , Sym
      { symName = "bar.v.triple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Fence
      , symText = "\10624"
      }
  , Sym
      { symName = "bar.v.broken"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\166"
      }
  , Sym
      { symName = "bar.v.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10678"
      }
  , Sym
      { symName = "bar.h"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8213"
      }
  , Sym
      { symName = "because"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8757"
      }
  , Sym
      { symName = "beta"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\946"
      }
  , Sym
      { symName = "beta.alt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\976"
      }
  , Sym
      { symName = "beth"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\1489"
      }
  , Sym
      { symName = "bitcoin"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8383"
      }
  , Sym
      { symName = "bot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8869"
      }
  , Sym
      { symName = "bowtie.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8904"
      }
  , Sym
      { symName = "bowtie.stroked.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10781"
      }
  , Sym
      { symName = "bowtie.stroked.big.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10197"
      }
  , Sym
      { symName = "bowtie.stroked.big.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10198"
      }
  , Sym
      { symName = "bowtie.stroked.big.l.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10199"
      }
  , Sym
      { symName = "bowtie.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10707"
      }
  , Sym
      { symName = "bowtie.filled.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10705"
      }
  , Sym
      { symName = "bowtie.filled.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10706"
      }
  , Sym
      { symName = "brace.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "{"
      }
  , Sym
      { symName = "brace.l.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\10627"
      }
  , Sym
      { symName = "brace.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "}"
      }
  , Sym
      { symName = "brace.r.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10628"
      }
  , Sym
      { symName = "brace.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9182"
      }
  , Sym
      { symName = "brace.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9183"
      }
  , Sym
      { symName = "bracket.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "["
      }
  , Sym
      { symName = "bracket.l.tick.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\10637"
      }
  , Sym
      { symName = "bracket.l.tick.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\10639"
      }
  , Sym
      { symName = "bracket.l.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\10214"
      }
  , Sym
      { symName = "bracket.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "]"
      }
  , Sym
      { symName = "bracket.r.tick.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10640"
      }
  , Sym
      { symName = "bracket.r.tick.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10638"
      }
  , Sym
      { symName = "bracket.r.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10215"
      }
  , Sym
      { symName = "bracket.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9140"
      }
  , Sym
      { symName = "bracket.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9141"
      }
  , Sym
      { symName = "breve"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\728"
      }
  , Sym
      { symName = "bullet"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8226"
      }
  , Sym
      { symName = "bullet.op"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8729"
      }
  , Sym
      { symName = "bullet.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10687"
      }
  , Sym
      { symName = "bullet.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9702"
      }
  , Sym
      { symName = "bullet.stroked.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10686"
      }
  , Sym
      { symName = "bullet.hole"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9688"
      }
  , Sym
      { symName = "bullet.hyph"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8259"
      }
  , Sym
      { symName = "bullet.tri"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8227"
      }
  , Sym
      { symName = "bullet.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8268"
      }
  , Sym
      { symName = "bullet.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8269"
      }
  , Sym
      { symName = "caret"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8248"
      }
  , Sym
      { symName = "caron"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\711"
      }
  , Sym
      { symName = "cc"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127341"
      }
  , Sym
      { symName = "cc.by"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127343"
      }
  , Sym
      { symName = "cc.nc"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127247"
      }
  , Sym
      { symName = "cc.nd"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8860"
      }
  , Sym
      { symName = "cc.public"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127342"
      }
  , Sym
      { symName = "cc.sa"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127246"
      }
  , Sym
      { symName = "cc.zero"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127245"
      }
  , Sym
      { symName = "cedi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8373"
      }
  , Sym
      { symName = "ceil.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\8968"
      }
  , Sym
      { symName = "ceil.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8969"
      }
  , Sym
      { symName = "cent"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\162"
      }
  , Sym
      { symName = "checkmark"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10003"
      }
  , Sym
      { symName = "checkmark.light"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128504"
      }
  , Sym
      { symName = "checkmark.heavy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10004"
      }
  , Sym
      { symName = "chevron.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\10216"
      }
  , Sym
      { symName = "chevron.l.curly"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\10748"
      }
  , Sym
      { symName = "chevron.l.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\10641"
      }
  , Sym
      { symName = "chevron.l.closed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\10633"
      }
  , Sym
      { symName = "chevron.l.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\10218"
      }
  , Sym
      { symName = "chevron.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10217"
      }
  , Sym
      { symName = "chevron.r.curly"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10749"
      }
  , Sym
      { symName = "chevron.r.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10642"
      }
  , Sym
      { symName = "chevron.r.closed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10634"
      }
  , Sym
      { symName = "chevron.r.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10219"
      }
  , Sym
      { symName = "chi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\967"
      }
  , Sym
      { symName = "circle.stroked"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9675"
      }
  , Sym
      { symName = "circle.stroked.tiny"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8728"
      }
  , Sym
      { symName = "circle.stroked.small"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9900"
      }
  , Sym
      { symName = "circle.stroked.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9711"
      }
  , Sym
      { symName = "circle.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9679"
      }
  , Sym
      { symName = "circle.filled.tiny"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10625"
      }
  , Sym
      { symName = "circle.filled.small"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8729"
      }
  , Sym
      { symName = "circle.filled.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11044"
      }
  , Sym
      { symName = "circle.dotted"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9676"
      }
  , Sym
      { symName = "co"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8453"
      }
  , Sym
      { symName = "colon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = ":"
      }
  , Sym
      { symName = "colon.currency"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8353"
      }
  , Sym
      { symName = "colon.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8759"
      }
  , Sym
      { symName = "colon.tri"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8285"
      }
  , Sym
      { symName = "colon.tri.op"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10998"
      }
  , Sym
      { symName = "colon.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8788"
      }
  , Sym
      { symName = "colon.double.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10868"
      }
  , Sym
      { symName = "comma"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Punctuation
      , symText = ","
      }
  , Sym
      { symName = "comma.inv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11826"
      }
  , Sym
      { symName = "comma.rev"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11841"
      }
  , Sym
      { symName = "complement"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8705"
      }
  , Sym
      { symName = "compose"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8728"
      }
  , Sym
      { symName = "compose.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8858"
      }
  , Sym
      { symName = "control.ack"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9222"
      }
  , Sym
      { symName = "control.bel"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9223"
      }
  , Sym
      { symName = "control.bs"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9224"
      }
  , Sym
      { symName = "control.can"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9240"
      }
  , Sym
      { symName = "control.cr"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9229"
      }
  , Sym
      { symName = "control.dc.one"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9233"
      }
  , Sym
      { symName = "control.dc.two"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9234"
      }
  , Sym
      { symName = "control.dc.three"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9235"
      }
  , Sym
      { symName = "control.dc.four"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9236"
      }
  , Sym
      { symName = "control.del"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9249"
      }
  , Sym
      { symName = "control.dle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9232"
      }
  , Sym
      { symName = "control.em"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9241"
      }
  , Sym
      { symName = "control.enq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9221"
      }
  , Sym
      { symName = "control.eot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9220"
      }
  , Sym
      { symName = "control.esc"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9243"
      }
  , Sym
      { symName = "control.etb"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9239"
      }
  , Sym
      { symName = "control.etx"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9219"
      }
  , Sym
      { symName = "control.ff"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9228"
      }
  , Sym
      { symName = "control.fs"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9244"
      }
  , Sym
      { symName = "control.gs"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9245"
      }
  , Sym
      { symName = "control.ht"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9225"
      }
  , Sym
      { symName = "control.lf"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9226"
      }
  , Sym
      { symName = "control.nak"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9237"
      }
  , Sym
      { symName = "control.nl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9252"
      }
  , Sym
      { symName = "control.nul"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9216"
      }
  , Sym
      { symName = "control.rs"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9246"
      }
  , Sym
      { symName = "control.si"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9231"
      }
  , Sym
      { symName = "control.so"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9230"
      }
  , Sym
      { symName = "control.soh"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9217"
      }
  , Sym
      { symName = "control.sp"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9248"
      }
  , Sym
      { symName = "control.stx"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9218"
      }
  , Sym
      { symName = "control.sub"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9242"
      }
  , Sym
      { symName = "control.syn"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9238"
      }
  , Sym
      { symName = "control.us"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9247"
      }
  , Sym
      { symName = "control.vt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9227"
      }
  , Sym
      { symName = "convolve"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8727"
      }
  , Sym
      { symName = "convolve.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8859"
      }
  , Sym
      { symName = "copyleft"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127279"
      }
  , Sym
      { symName = "copyright"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\169"
      }
  , Sym
      { symName = "copyright.sound"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8471"
      }
  , Sym
      { symName = "corner.l.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\8988"
      }
  , Sym
      { symName = "corner.l.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\8990"
      }
  , Sym
      { symName = "corner.r.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8989"
      }
  , Sym
      { symName = "corner.r.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8991"
      }
  , Sym
      { symName = "crossmark"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10007"
      }
  , Sym
      { symName = "crossmark.heavy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10008"
      }
  , Sym
      { symName = "currency"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\164"
      }
  , Sym
      { symName = "dagger"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8224"
      }
  , Sym
      { symName = "dagger.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8225"
      }
  , Sym
      { symName = "dagger.triple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11851"
      }
  , Sym
      { symName = "dagger.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11830"
      }
  , Sym
      { symName = "dagger.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11831"
      }
  , Sym
      { symName = "dagger.inv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11832"
      }
  , Sym
      { symName = "daleth"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\1491"
      }
  , Sym
      { symName = "dash.en"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = Punctuation
      , symText = "\8211"
      }
  , Sym
      { symName = "dash.em"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Punctuation
      , symText = "\8212"
      }
  , Sym
      { symName = "dash.em.two"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11834"
      }
  , Sym
      { symName = "dash.em.three"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11835"
      }
  , Sym
      { symName = "dash.fig"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Punctuation
      , symText = "\8210"
      }
  , Sym
      { symName = "dash.colon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8761"
      }
  , Sym
      { symName = "dash.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8861"
      }
  , Sym
      { symName = "dash.wave"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\12316"
      }
  , Sym
      { symName = "dash.wave.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\12336"
      }
  , Sym
      { symName = "degree"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\176"
      }
  , Sym
      { symName = "delta"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\948"
      }
  , Sym
      { symName = "diaer"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\168"
      }
  , Sym
      { symName = "diameter"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8960"
      }
  , Sym
      { symName = "diamond.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9671"
      }
  , Sym
      { symName = "diamond.stroked.small"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8900"
      }
  , Sym
      { symName = "diamond.stroked.medium"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11046"
      }
  , Sym
      { symName = "diamond.stroked.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10192"
      }
  , Sym
      { symName = "diamond.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9670"
      }
  , Sym
      { symName = "diamond.filled.medium"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11045"
      }
  , Sym
      { symName = "diamond.filled.small"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11049"
      }
  , Sym
      { symName = "die.six"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9861"
      }
  , Sym
      { symName = "die.five"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9860"
      }
  , Sym
      { symName = "die.four"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9859"
      }
  , Sym
      { symName = "die.three"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9858"
      }
  , Sym
      { symName = "die.two"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9857"
      }
  , Sym
      { symName = "die.one"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9856"
      }
  , Sym
      { symName = "digamma"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\989"
      }
  , Sym
      { symName = "div"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\247"
      }
  , Sym
      { symName = "div.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10808"
      }
  , Sym
      { symName = "div.slanted.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10684"
      }
  , Sym
      { symName = "divides"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8739"
      }
  , Sym
      { symName = "divides.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8740"
      }
  , Sym
      { symName = "divides.not.rev"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10990"
      }
  , Sym
      { symName = "divides.struck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10186"
      }
  , Sym
      { symName = "dollar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "$"
      }
  , Sym
      { symName = "dong"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8363"
      }
  , Sym
      { symName = "dorome"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\2046"
      }
  , Sym
      { symName = "dot.op"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8901"
      }
  , Sym
      { symName = "dot.basic"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "."
      }
  , Sym
      { symName = "dot.c"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\183"
      }
  , Sym
      { symName = "dot.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8857"
      }
  , Sym
      { symName = "dot.o.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10752"
      }
  , Sym
      { symName = "dot.square"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8865"
      }
  , Sym
      { symName = "dot.double"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\168"
      }
  , Sym
      { symName = "dot.triple"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8411"
      }
  , Sym
      { symName = "dot.quad"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8412"
      }
  , Sym
      { symName = "dotless.i"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\305"
      }
  , Sym
      { symName = "dotless.j"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\567"
      }
  , Sym
      { symName = "dots.h.c"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8943"
      }
  , Sym
      { symName = "dots.h"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8230"
      }
  , Sym
      { symName = "dots.v"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8942"
      }
  , Sym
      { symName = "dots.down"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8945"
      }
  , Sym
      { symName = "dots.up"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8944"
      }
  , Sym
      { symName = "dram"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\1423"
      }
  , Sym
      { symName = "earth"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128808"
      }
  , Sym
      { symName = "earth.alt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9793"
      }
  , Sym
      { symName = "ell"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\8467"
      }
  , Sym
      { symName = "ellipse.stroked.h"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11053"
      }
  , Sym
      { symName = "ellipse.stroked.v"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11055"
      }
  , Sym
      { symName = "ellipse.filled.h"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11052"
      }
  , Sym
      { symName = "ellipse.filled.v"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11054"
      }
  , Sym
      { symName = "emptyset"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8709"
      }
  , Sym
      { symName = "emptyset.zero"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8709\65024"
      }
  , Sym
      { symName = "emptyset.arrow.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10675"
      }
  , Sym
      { symName = "emptyset.arrow.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10676"
      }
  , Sym
      { symName = "emptyset.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10673"
      }
  , Sym
      { symName = "emptyset.circle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10674"
      }
  , Sym
      { symName = "emptyset.rev"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10672"
      }
  , Sym
      { symName = "epsilon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\949"
      }
  , Sym
      { symName = "epsilon.alt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\1013"
      }
  , Sym
      { symName = "epsilon.alt.rev"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\1014"
      }
  , Sym
      { symName = "eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "="
      }
  , Sym
      { symName = "eq.ast"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10862"
      }
  , Sym
      { symName = "eq.star"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8795"
      }
  , Sym
      { symName = "eq.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8860"
      }
  , Sym
      { symName = "eq.colon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8789"
      }
  , Sym
      { symName = "eq.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8784"
      }
  , Sym
      { symName = "eq.dots"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8785"
      }
  , Sym
      { symName = "eq.dots.down"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8786"
      }
  , Sym
      { symName = "eq.dots.up"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8787"
      }
  , Sym
      { symName = "eq.def"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8797"
      }
  , Sym
      { symName = "eq.delta"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8796"
      }
  , Sym
      { symName = "eq.equi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8794"
      }
  , Sym
      { symName = "eq.est"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8793"
      }
  , Sym
      { symName = "eq.gt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8925"
      }
  , Sym
      { symName = "eq.lt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8924"
      }
  , Sym
      { symName = "eq.m"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8798"
      }
  , Sym
      { symName = "eq.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8800"
      }
  , Sym
      { symName = "eq.prec"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8926"
      }
  , Sym
      { symName = "eq.quest"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8799"
      }
  , Sym
      { symName = "eq.succ"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8927"
      }
  , Sym
      { symName = "eq.triple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8801"
      }
  , Sym
      { symName = "eq.triple.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8802"
      }
  , Sym
      { symName = "eq.quad"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8803"
      }
  , Sym
      { symName = "equiv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8801"
      }
  , Sym
      { symName = "equiv.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8802"
      }
  , Sym
      { symName = "errorbar.square.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10734"
      }
  , Sym
      { symName = "errorbar.square.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10735"
      }
  , Sym
      { symName = "errorbar.diamond.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10736"
      }
  , Sym
      { symName = "errorbar.diamond.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10737"
      }
  , Sym
      { symName = "errorbar.circle.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10738"
      }
  , Sym
      { symName = "errorbar.circle.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10739"
      }
  , Sym
      { symName = "eta"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\951"
      }
  , Sym
      { symName = "euro"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8364"
      }
  , Sym
      { symName = "excl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "!"
      }
  , Sym
      { symName = "excl.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8252"
      }
  , Sym
      { symName = "excl.inv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Punctuation
      , symText = "\161"
      }
  , Sym
      { symName = "excl.quest"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8265"
      }
  , Sym
      { symName = "exists"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8707"
      }
  , Sym
      { symName = "exists.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8708"
      }
  , Sym
      { symName = "fence.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\10712"
      }
  , Sym
      { symName = "fence.l.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\10714"
      }
  , Sym
      { symName = "fence.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10713"
      }
  , Sym
      { symName = "fence.r.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10715"
      }
  , Sym
      { symName = "fence.dotted"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Fence
      , symText = "\10649"
      }
  , Sym
      { symName = "flat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9837"
      }
  , Sym
      { symName = "flat.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119084"
      }
  , Sym
      { symName = "flat.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119085"
      }
  , Sym
      { symName = "flat.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119083"
      }
  , Sym
      { symName = "flat.quarter"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119091"
      }
  , Sym
      { symName = "floor.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\8970"
      }
  , Sym
      { symName = "floor.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8971"
      }
  , Sym
      { symName = "floral"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10086"
      }
  , Sym
      { symName = "floral.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9753"
      }
  , Sym
      { symName = "floral.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10087"
      }
  , Sym
      { symName = "forall"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8704"
      }
  , Sym
      { symName = "forces"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8873"
      }
  , Sym
      { symName = "forces.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8878"
      }
  , Sym
      { symName = "frown"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8994"
      }
  , Sym
      { symName = "gamma"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\947"
      }
  , Sym
      { symName = "gender.female"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9792"
      }
  , Sym
      { symName = "gender.female.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9890"
      }
  , Sym
      { symName = "gender.female.male"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9892"
      }
  , Sym
      { symName = "gender.intersex"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9893"
      }
  , Sym
      { symName = "gender.male"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9794"
      }
  , Sym
      { symName = "gender.male.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9891"
      }
  , Sym
      { symName = "gender.male.female"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9892"
      }
  , Sym
      { symName = "gender.male.stroke"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9894"
      }
  , Sym
      { symName = "gender.male.stroke.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9896"
      }
  , Sym
      { symName = "gender.male.stroke.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9897"
      }
  , Sym
      { symName = "gender.neuter"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9906"
      }
  , Sym
      { symName = "gender.trans"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9895"
      }
  , Sym
      { symName = "gimel"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\1490"
      }
  , Sym
      { symName = "gradient"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8711"
      }
  , Sym
      { symName = "grave"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "`"
      }
  , Sym
      { symName = "gt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = ">"
      }
  , Sym
      { symName = "gt.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10689"
      }
  , Sym
      { symName = "gt.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8919"
      }
  , Sym
      { symName = "gt.quest"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10876"
      }
  , Sym
      { symName = "gt.approx"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10886"
      }
  , Sym
      { symName = "gt.arc"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10919"
      }
  , Sym
      { symName = "gt.arc.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10921"
      }
  , Sym
      { symName = "gt.closed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8883"
      }
  , Sym
      { symName = "gt.closed.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8885"
      }
  , Sym
      { symName = "gt.closed.eq.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8941"
      }
  , Sym
      { symName = "gt.closed.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8939"
      }
  , Sym
      { symName = "gt.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8811"
      }
  , Sym
      { symName = "gt.double.nested"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10914"
      }
  , Sym
      { symName = "gt.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8805"
      }
  , Sym
      { symName = "gt.eq.slant"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10878"
      }
  , Sym
      { symName = "gt.eq.lt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8923"
      }
  , Sym
      { symName = "gt.eq.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8817"
      }
  , Sym
      { symName = "gt.equiv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8807"
      }
  , Sym
      { symName = "gt.lt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8823"
      }
  , Sym
      { symName = "gt.lt.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8825"
      }
  , Sym
      { symName = "gt.neq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10888"
      }
  , Sym
      { symName = "gt.napprox"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10890"
      }
  , Sym
      { symName = "gt.nequiv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8809"
      }
  , Sym
      { symName = "gt.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8815"
      }
  , Sym
      { symName = "gt.ntilde"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8935"
      }
  , Sym
      { symName = "gt.tilde"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8819"
      }
  , Sym
      { symName = "gt.tilde.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8821"
      }
  , Sym
      { symName = "gt.tri"
      , symIsAccent = False
      , symDeprecation =
          Just "`gt.tri` is deprecated, use `gt.closed` instead"
      , symMathClass = Relation
      , symText = "\8883"
      }
  , Sym
      { symName = "gt.tri.eq"
      , symIsAccent = False
      , symDeprecation =
          Just "`gt.tri.eq` is deprecated, use `gt.closed.eq` instead"
      , symMathClass = Relation
      , symText = "\8885"
      }
  , Sym
      { symName = "gt.tri.eq.not"
      , symIsAccent = False
      , symDeprecation =
          Just
            "`gt.tri.eq.not` is deprecated, use `gt.closed.eq.not` instead"
      , symMathClass = Relation
      , symText = "\8941"
      }
  , Sym
      { symName = "gt.tri.not"
      , symIsAccent = False
      , symDeprecation =
          Just "`gt.tri.not` is deprecated, use `gt.closed.not` instead"
      , symMathClass = Relation
      , symText = "\8939"
      }
  , Sym
      { symName = "gt.triple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8921"
      }
  , Sym
      { symName = "gt.triple.nested"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11000"
      }
  , Sym
      { symName = "guarani"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8370"
      }
  , Sym
      { symName = "harpoon.rt"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8640"
      }
  , Sym
      { symName = "harpoon.rt.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10587"
      }
  , Sym
      { symName = "harpoon.rt.stop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10579"
      }
  , Sym
      { symName = "harpoon.rb"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8641"
      }
  , Sym
      { symName = "harpoon.rb.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10591"
      }
  , Sym
      { symName = "harpoon.rb.stop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10583"
      }
  , Sym
      { symName = "harpoon.lt"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8636"
      }
  , Sym
      { symName = "harpoon.lt.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10586"
      }
  , Sym
      { symName = "harpoon.lt.stop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10578"
      }
  , Sym
      { symName = "harpoon.lb"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8637"
      }
  , Sym
      { symName = "harpoon.lb.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10590"
      }
  , Sym
      { symName = "harpoon.lb.stop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10582"
      }
  , Sym
      { symName = "harpoon.tl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8639"
      }
  , Sym
      { symName = "harpoon.tl.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10592"
      }
  , Sym
      { symName = "harpoon.tl.stop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10584"
      }
  , Sym
      { symName = "harpoon.tr"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8638"
      }
  , Sym
      { symName = "harpoon.tr.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10588"
      }
  , Sym
      { symName = "harpoon.tr.stop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10580"
      }
  , Sym
      { symName = "harpoon.bl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8643"
      }
  , Sym
      { symName = "harpoon.bl.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10593"
      }
  , Sym
      { symName = "harpoon.bl.stop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10585"
      }
  , Sym
      { symName = "harpoon.br"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8642"
      }
  , Sym
      { symName = "harpoon.br.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10589"
      }
  , Sym
      { symName = "harpoon.br.stop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10581"
      }
  , Sym
      { symName = "harpoon.lt.rt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10574"
      }
  , Sym
      { symName = "harpoon.lb.rb"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10576"
      }
  , Sym
      { symName = "harpoon.lb.rt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10571"
      }
  , Sym
      { symName = "harpoon.lt.rb"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10570"
      }
  , Sym
      { symName = "harpoon.tl.bl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10577"
      }
  , Sym
      { symName = "harpoon.tr.br"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10575"
      }
  , Sym
      { symName = "harpoon.tl.br"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10573"
      }
  , Sym
      { symName = "harpoon.tr.bl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10572"
      }
  , Sym
      { symName = "harpoons.rtrb"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10596"
      }
  , Sym
      { symName = "harpoons.blbr"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10597"
      }
  , Sym
      { symName = "harpoons.bltr"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10607"
      }
  , Sym
      { symName = "harpoons.lbrb"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10599"
      }
  , Sym
      { symName = "harpoons.ltlb"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10594"
      }
  , Sym
      { symName = "harpoons.ltrb"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8651"
      }
  , Sym
      { symName = "harpoons.ltrt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10598"
      }
  , Sym
      { symName = "harpoons.rblb"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10601"
      }
  , Sym
      { symName = "harpoons.rtlb"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8652"
      }
  , Sym
      { symName = "harpoons.rtlt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10600"
      }
  , Sym
      { symName = "harpoons.tlbr"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10606"
      }
  , Sym
      { symName = "harpoons.tltr"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10595"
      }
  , Sym
      { symName = "hash"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "#"
      }
  , Sym
      { symName = "hat"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "^"
      }
  , Sym
      { symName = "hexa.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11041"
      }
  , Sym
      { symName = "hexa.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11042"
      }
  , Sym
      { symName = "hourglass.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10710"
      }
  , Sym
      { symName = "hourglass.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10711"
      }
  , Sym
      { symName = "hryvnia"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8372"
      }
  , Sym
      { symName = "hyph"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Punctuation
      , symText = "\8208"
      }
  , Sym
      { symName = "hyph.minus"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "-"
      }
  , Sym
      { symName = "hyph.nobreak"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8209"
      }
  , Sym
      { symName = "hyph.point"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8231"
      }
  , Sym
      { symName = "hyph.soft"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\173"
      }
  , Sym
      { symName = "image"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8887"
      }
  , Sym
      { symName = "in"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8712"
      }
  , Sym
      { symName = "in.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8713"
      }
  , Sym
      { symName = "in.rev"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8715"
      }
  , Sym
      { symName = "in.rev.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8716"
      }
  , Sym
      { symName = "in.rev.small"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8717"
      }
  , Sym
      { symName = "in.small"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8714"
      }
  , Sym
      { symName = "infinity"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8734"
      }
  , Sym
      { symName = "infinity.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10718"
      }
  , Sym
      { symName = "infinity.incomplete"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10716"
      }
  , Sym
      { symName = "infinity.tie"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10717"
      }
  , Sym
      { symName = "integral"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8747"
      }
  , Sym
      { symName = "integral.arrow.hook"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10775"
      }
  , Sym
      { symName = "integral.ccw"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10769"
      }
  , Sym
      { symName = "integral.cont"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8750"
      }
  , Sym
      { symName = "integral.cont.ccw"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8755"
      }
  , Sym
      { symName = "integral.cont.cw"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8754"
      }
  , Sym
      { symName = "integral.cw"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8753"
      }
  , Sym
      { symName = "integral.dash"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10765"
      }
  , Sym
      { symName = "integral.dash.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10766"
      }
  , Sym
      { symName = "integral.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8748"
      }
  , Sym
      { symName = "integral.quad"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10764"
      }
  , Sym
      { symName = "integral.inter"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10777"
      }
  , Sym
      { symName = "integral.slash"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10767"
      }
  , Sym
      { symName = "integral.square"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10774"
      }
  , Sym
      { symName = "integral.surf"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8751"
      }
  , Sym
      { symName = "integral.times"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10776"
      }
  , Sym
      { symName = "integral.triple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8749"
      }
  , Sym
      { symName = "integral.union"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10778"
      }
  , Sym
      { symName = "integral.vol"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8752"
      }
  , Sym
      { symName = "inter"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8745"
      }
  , Sym
      { symName = "inter.serif"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8745\65024"
      }
  , Sym
      { symName = "inter.and"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10820"
      }
  , Sym
      { symName = "inter.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8898"
      }
  , Sym
      { symName = "inter.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10816"
      }
  , Sym
      { symName = "inter.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8914"
      }
  , Sym
      { symName = "inter.sq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8851"
      }
  , Sym
      { symName = "inter.sq.serif"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8851\65024"
      }
  , Sym
      { symName = "inter.sq.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10757"
      }
  , Sym
      { symName = "inter.sq.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10830"
      }
  , Sym
      { symName = "interleave"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10996"
      }
  , Sym
      { symName = "interleave.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11004"
      }
  , Sym
      { symName = "interleave.struck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10997"
      }
  , Sym
      { symName = "interrobang"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8253"
      }
  , Sym
      { symName = "interrobang.inv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11800"
      }
  , Sym
      { symName = "iota"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\953"
      }
  , Sym
      { symName = "iota.inv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8489"
      }
  , Sym
      { symName = "join"
      , symIsAccent = False
      , symDeprecation =
          Just "`join` is deprecated, use `bowtie.big` instead"
      , symMathClass = None
      , symText = "\10781"
      }
  , Sym
      { symName = "join.r"
      , symIsAccent = False
      , symDeprecation =
          Just "`join` is deprecated, use `bowtie.big` instead"
      , symMathClass = None
      , symText = "\10198"
      }
  , Sym
      { symName = "join.l"
      , symIsAccent = False
      , symDeprecation =
          Just "`join` is deprecated, use `bowtie.big` instead"
      , symMathClass = None
      , symText = "\10197"
      }
  , Sym
      { symName = "join.l.r"
      , symIsAccent = False
      , symDeprecation =
          Just "`join` is deprecated, use `bowtie.big` instead"
      , symMathClass = None
      , symText = "\10199"
      }
  , Sym
      { symName = "jupiter"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9795"
      }
  , Sym
      { symName = "kappa"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\954"
      }
  , Sym
      { symName = "kappa.alt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\1008"
      }
  , Sym
      { symName = "kip"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8365"
      }
  , Sym
      { symName = "lambda"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\955"
      }
  , Sym
      { symName = "laplace"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8710"
      }
  , Sym
      { symName = "lari"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8382"
      }
  , Sym
      { symName = "lat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10923"
      }
  , Sym
      { symName = "lat.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10925"
      }
  , Sym
      { symName = "lira"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8378"
      }
  , Sym
      { symName = "lozenge.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9674"
      }
  , Sym
      { symName = "lozenge.stroked.small"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11051"
      }
  , Sym
      { symName = "lozenge.stroked.medium"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11048"
      }
  , Sym
      { symName = "lozenge.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10731"
      }
  , Sym
      { symName = "lozenge.filled.small"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11050"
      }
  , Sym
      { symName = "lozenge.filled.medium"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11047"
      }
  , Sym
      { symName = "lrm"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8206"
      }
  , Sym
      { symName = "lt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "<"
      }
  , Sym
      { symName = "lt.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10688"
      }
  , Sym
      { symName = "lt.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8918"
      }
  , Sym
      { symName = "lt.quest"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10875"
      }
  , Sym
      { symName = "lt.approx"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10885"
      }
  , Sym
      { symName = "lt.arc"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10918"
      }
  , Sym
      { symName = "lt.arc.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10920"
      }
  , Sym
      { symName = "lt.closed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8882"
      }
  , Sym
      { symName = "lt.closed.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8884"
      }
  , Sym
      { symName = "lt.closed.eq.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8940"
      }
  , Sym
      { symName = "lt.closed.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8938"
      }
  , Sym
      { symName = "lt.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8810"
      }
  , Sym
      { symName = "lt.double.nested"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10913"
      }
  , Sym
      { symName = "lt.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8804"
      }
  , Sym
      { symName = "lt.eq.slant"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10877"
      }
  , Sym
      { symName = "lt.eq.gt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8922"
      }
  , Sym
      { symName = "lt.eq.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8816"
      }
  , Sym
      { symName = "lt.equiv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8806"
      }
  , Sym
      { symName = "lt.gt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8822"
      }
  , Sym
      { symName = "lt.gt.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8824"
      }
  , Sym
      { symName = "lt.neq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10887"
      }
  , Sym
      { symName = "lt.napprox"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10889"
      }
  , Sym
      { symName = "lt.nequiv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8808"
      }
  , Sym
      { symName = "lt.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8814"
      }
  , Sym
      { symName = "lt.ntilde"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8934"
      }
  , Sym
      { symName = "lt.tilde"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8818"
      }
  , Sym
      { symName = "lt.tilde.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8820"
      }
  , Sym
      { symName = "lt.tri"
      , symIsAccent = False
      , symDeprecation =
          Just "`lt.tri` is deprecated, use `lt.closed` instead"
      , symMathClass = Relation
      , symText = "\8882"
      }
  , Sym
      { symName = "lt.tri.eq"
      , symIsAccent = False
      , symDeprecation =
          Just "`lt.tri.eq` is deprecated, use `lt.closed.eq` instead"
      , symMathClass = Relation
      , symText = "\8884"
      }
  , Sym
      { symName = "lt.tri.eq.not"
      , symIsAccent = False
      , symDeprecation =
          Just
            "`lt.tri.eq.not` is deprecated, use `lt.closed.eq.not` instead"
      , symMathClass = Relation
      , symText = "\8940"
      }
  , Sym
      { symName = "lt.tri.not"
      , symIsAccent = False
      , symDeprecation =
          Just "`lt.tri.not` is deprecated, use `lt.closed.not` instead"
      , symMathClass = Relation
      , symText = "\8938"
      }
  , Sym
      { symName = "lt.triple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8920"
      }
  , Sym
      { symName = "lt.triple.nested"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10999"
      }
  , Sym
      { symName = "macron"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\175"
      }
  , Sym
      { symName = "maltese"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10016"
      }
  , Sym
      { symName = "manat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8380"
      }
  , Sym
      { symName = "mapsfrom"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8612"
      }
  , Sym
      { symName = "mapsfrom.long"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10235"
      }
  , Sym
      { symName = "mapsto"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8614"
      }
  , Sym
      { symName = "mapsto.long"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10236"
      }
  , Sym
      { symName = "mars"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9794"
      }
  , Sym
      { symName = "mercury"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9791"
      }
  , Sym
      { symName = "minus"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8722"
      }
  , Sym
      { symName = "minus.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8854"
      }
  , Sym
      { symName = "minus.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8760"
      }
  , Sym
      { symName = "minus.plus"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8723"
      }
  , Sym
      { symName = "minus.square"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8863"
      }
  , Sym
      { symName = "minus.tilde"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8770"
      }
  , Sym
      { symName = "minus.triangle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10810"
      }
  , Sym
      { symName = "miny"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10751"
      }
  , Sym
      { symName = "models"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8871"
      }
  , Sym
      { symName = "mu"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\956"
      }
  , Sym
      { symName = "multimap"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8888"
      }
  , Sym
      { symName = "multimap.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10719"
      }
  , Sym
      { symName = "mustache.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\9136"
      }
  , Sym
      { symName = "mustache.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9137"
      }
  , Sym
      { symName = "nabla"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8711"
      }
  , Sym
      { symName = "naira"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8358"
      }
  , Sym
      { symName = "natural"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9838"
      }
  , Sym
      { symName = "natural.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119086"
      }
  , Sym
      { symName = "natural.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119087"
      }
  , Sym
      { symName = "neptune"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9798"
      }
  , Sym
      { symName = "neptune.alt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11209"
      }
  , Sym
      { symName = "not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\172"
      }
  , Sym
      { symName = "note.up"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127900"
      }
  , Sym
      { symName = "note.down"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127901"
      }
  , Sym
      { symName = "note.whole"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119133"
      }
  , Sym
      { symName = "note.half"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119134"
      }
  , Sym
      { symName = "note.quarter"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119135"
      }
  , Sym
      { symName = "note.quarter.alt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9833"
      }
  , Sym
      { symName = "note.eighth"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119136"
      }
  , Sym
      { symName = "note.eighth.alt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9834"
      }
  , Sym
      { symName = "note.eighth.beamed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9835"
      }
  , Sym
      { symName = "note.sixteenth"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119137"
      }
  , Sym
      { symName = "note.sixteenth.beamed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9836"
      }
  , Sym
      { symName = "note.grace"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119189"
      }
  , Sym
      { symName = "note.grace.slash"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119188"
      }
  , Sym
      { symName = "nothing"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8709"
      }
  , Sym
      { symName = "nothing.zero"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8709\65024"
      }
  , Sym
      { symName = "nothing.arrow.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10675"
      }
  , Sym
      { symName = "nothing.arrow.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10676"
      }
  , Sym
      { symName = "nothing.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10673"
      }
  , Sym
      { symName = "nothing.circle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10674"
      }
  , Sym
      { symName = "nothing.rev"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10672"
      }
  , Sym
      { symName = "nu"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\957"
      }
  , Sym
      { symName = "numero"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8470"
      }
  , Sym
      { symName = "omega"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\969"
      }
  , Sym
      { symName = "omicron"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\959"
      }
  , Sym
      { symName = "oo"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8734"
      }
  , Sym
      { symName = "or"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8744"
      }
  , Sym
      { symName = "or.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8897"
      }
  , Sym
      { symName = "or.curly"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8910"
      }
  , Sym
      { symName = "or.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10183"
      }
  , Sym
      { symName = "or.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10836"
      }
  , Sym
      { symName = "original"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8886"
      }
  , Sym
      { symName = "parallel"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8741"
      }
  , Sym
      { symName = "parallel.struck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10994"
      }
  , Sym
      { symName = "parallel.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10679"
      }
  , Sym
      { symName = "parallel.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8917"
      }
  , Sym
      { symName = "parallel.equiv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10856"
      }
  , Sym
      { symName = "parallel.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8742"
      }
  , Sym
      { symName = "parallel.slanted.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10723"
      }
  , Sym
      { symName = "parallel.slanted.eq.tilde"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10724"
      }
  , Sym
      { symName = "parallel.slanted.equiv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10725"
      }
  , Sym
      { symName = "parallel.tilde"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10995"
      }
  , Sym
      { symName = "parallelogram.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9649"
      }
  , Sym
      { symName = "parallelogram.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9648"
      }
  , Sym
      { symName = "paren.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "("
      }
  , Sym
      { symName = "paren.l.flat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\10222"
      }
  , Sym
      { symName = "paren.l.closed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\10631"
      }
  , Sym
      { symName = "paren.l.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\10629"
      }
  , Sym
      { symName = "paren.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = ")"
      }
  , Sym
      { symName = "paren.r.flat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10223"
      }
  , Sym
      { symName = "paren.r.closed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10632"
      }
  , Sym
      { symName = "paren.r.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10630"
      }
  , Sym
      { symName = "paren.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9180"
      }
  , Sym
      { symName = "paren.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9181"
      }
  , Sym
      { symName = "partial"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8706"
      }
  , Sym
      { symName = "pataca"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "$"
      }
  , Sym
      { symName = "pee"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\8472"
      }
  , Sym
      { symName = "penta.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11040"
      }
  , Sym
      { symName = "penta.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11039"
      }
  , Sym
      { symName = "percent"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "%"
      }
  , Sym
      { symName = "permille"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8240"
      }
  , Sym
      { symName = "permyriad"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8241"
      }
  , Sym
      { symName = "perp"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10178"
      }
  , Sym
      { symName = "perp.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10681"
      }
  , Sym
      { symName = "peso"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "$"
      }
  , Sym
      { symName = "peso.philippine"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8369"
      }
  , Sym
      { symName = "phi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\966"
      }
  , Sym
      { symName = "phi.alt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\981"
      }
  , Sym
      { symName = "pi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\960"
      }
  , Sym
      { symName = "pi.alt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\982"
      }
  , Sym
      { symName = "pilcrow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\182"
      }
  , Sym
      { symName = "pilcrow.rev"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8267"
      }
  , Sym
      { symName = "planck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\295"
      }
  , Sym
      { symName = "plus"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "+"
      }
  , Sym
      { symName = "plus.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8853"
      }
  , Sym
      { symName = "plus.o.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10797"
      }
  , Sym
      { symName = "plus.o.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10798"
      }
  , Sym
      { symName = "plus.o.arrow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10228"
      }
  , Sym
      { symName = "plus.o.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10753"
      }
  , Sym
      { symName = "plus.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8724"
      }
  , Sym
      { symName = "plus.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10746"
      }
  , Sym
      { symName = "plus.minus"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\177"
      }
  , Sym
      { symName = "plus.square"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8862"
      }
  , Sym
      { symName = "plus.triangle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10809"
      }
  , Sym
      { symName = "plus.triple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10747"
      }
  , Sym
      { symName = "plus.hat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10787"
      }
  , Sym
      { symName = "pound"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\163"
      }
  , Sym
      { symName = "power.standby"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9211"
      }
  , Sym
      { symName = "power.on"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9213"
      }
  , Sym
      { symName = "power.off"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11096"
      }
  , Sym
      { symName = "power.on.off"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9212"
      }
  , Sym
      { symName = "power.sleep"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9214"
      }
  , Sym
      { symName = "prec"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8826"
      }
  , Sym
      { symName = "prec.approx"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10935"
      }
  , Sym
      { symName = "prec.curly.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8828"
      }
  , Sym
      { symName = "prec.curly.eq.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8928"
      }
  , Sym
      { symName = "prec.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10939"
      }
  , Sym
      { symName = "prec.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10927"
      }
  , Sym
      { symName = "prec.equiv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10931"
      }
  , Sym
      { symName = "prec.napprox"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10937"
      }
  , Sym
      { symName = "prec.neq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10929"
      }
  , Sym
      { symName = "prec.nequiv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10933"
      }
  , Sym
      { symName = "prec.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8832"
      }
  , Sym
      { symName = "prec.ntilde"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8936"
      }
  , Sym
      { symName = "prec.tilde"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8830"
      }
  , Sym
      { symName = "prime"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8242"
      }
  , Sym
      { symName = "prime.rev"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8245"
      }
  , Sym
      { symName = "prime.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8243"
      }
  , Sym
      { symName = "prime.double.rev"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8246"
      }
  , Sym
      { symName = "prime.triple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8244"
      }
  , Sym
      { symName = "prime.triple.rev"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8247"
      }
  , Sym
      { symName = "prime.quad"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8279"
      }
  , Sym
      { symName = "product"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8719"
      }
  , Sym
      { symName = "product.co"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8720"
      }
  , Sym
      { symName = "prop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8733"
      }
  , Sym
      { symName = "psi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\968"
      }
  , Sym
      { symName = "qed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8718"
      }
  , Sym
      { symName = "quest"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Punctuation
      , symText = "?"
      }
  , Sym
      { symName = "quest.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8263"
      }
  , Sym
      { symName = "quest.excl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8264"
      }
  , Sym
      { symName = "quest.inv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Punctuation
      , symText = "\191"
      }
  , Sym
      { symName = "quote.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\""
      }
  , Sym
      { symName = "quote.single"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "'"
      }
  , Sym
      { symName = "quote.l.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8220"
      }
  , Sym
      { symName = "quote.l.single"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8216"
      }
  , Sym
      { symName = "quote.r.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8221"
      }
  , Sym
      { symName = "quote.r.single"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8217"
      }
  , Sym
      { symName = "quote.chevron.l.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\171"
      }
  , Sym
      { symName = "quote.chevron.l.single"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8249"
      }
  , Sym
      { symName = "quote.chevron.r.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\187"
      }
  , Sym
      { symName = "quote.chevron.r.single"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8250"
      }
  , Sym
      { symName = "quote.high.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8223"
      }
  , Sym
      { symName = "quote.high.single"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8219"
      }
  , Sym
      { symName = "quote.low.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8222"
      }
  , Sym
      { symName = "quote.low.single"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8218"
      }
  , Sym
      { symName = "ratio"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8758"
      }
  , Sym
      { symName = "rect.stroked.h"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9645"
      }
  , Sym
      { symName = "rect.stroked.v"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9647"
      }
  , Sym
      { symName = "rect.filled.h"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9644"
      }
  , Sym
      { symName = "rect.filled.v"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9646"
      }
  , Sym
      { symName = "refmark"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8251"
      }
  , Sym
      { symName = "rest.whole"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119099"
      }
  , Sym
      { symName = "rest.multiple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119098"
      }
  , Sym
      { symName = "rest.multiple.measure"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119081"
      }
  , Sym
      { symName = "rest.half"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119100"
      }
  , Sym
      { symName = "rest.quarter"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119101"
      }
  , Sym
      { symName = "rest.eighth"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119102"
      }
  , Sym
      { symName = "rest.sixteenth"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119103"
      }
  , Sym
      { symName = "rho"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\961"
      }
  , Sym
      { symName = "rho.alt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\1009"
      }
  , Sym
      { symName = "riel"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\6107"
      }
  , Sym
      { symName = "riyal"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8385"
      }
  , Sym
      { symName = "rlm"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8207"
      }
  , Sym
      { symName = "ruble"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8381"
      }
  , Sym
      { symName = "rupee.indian"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8377"
      }
  , Sym
      { symName = "rupee.generic"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8360"
      }
  , Sym
      { symName = "rupee.tamil"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\3065"
      }
  , Sym
      { symName = "rupee.wancho"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\123647"
      }
  , Sym
      { symName = "saturn"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9796"
      }
  , Sym
      { symName = "section"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\167"
      }
  , Sym
      { symName = "semi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Punctuation
      , symText = ";"
      }
  , Sym
      { symName = "semi.inv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11829"
      }
  , Sym
      { symName = "semi.rev"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8271"
      }
  , Sym
      { symName = "sha"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\1096"
      }
  , Sym
      { symName = "sharp"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9839"
      }
  , Sym
      { symName = "sharp.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119088"
      }
  , Sym
      { symName = "sharp.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119089"
      }
  , Sym
      { symName = "sharp.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119082"
      }
  , Sym
      { symName = "sharp.quarter"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\119090"
      }
  , Sym
      { symName = "shekel"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8362"
      }
  , Sym
      { symName = "shell.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\10098"
      }
  , Sym
      { symName = "shell.l.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\10220"
      }
  , Sym
      { symName = "shell.l.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Opening
      , symText = "\10647"
      }
  , Sym
      { symName = "shell.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10099"
      }
  , Sym
      { symName = "shell.r.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10221"
      }
  , Sym
      { symName = "shell.r.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10648"
      }
  , Sym
      { symName = "shell.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9184"
      }
  , Sym
      { symName = "shell.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9185"
      }
  , Sym
      { symName = "sigma"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\963"
      }
  , Sym
      { symName = "sigma.alt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\962"
      }
  , Sym
      { symName = "slash"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "/"
      }
  , Sym
      { symName = "slash.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8856"
      }
  , Sym
      { symName = "slash.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\11005"
      }
  , Sym
      { symName = "slash.triple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\11003"
      }
  , Sym
      { symName = "slash.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10744"
      }
  , Sym
      { symName = "smash"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10803"
      }
  , Sym
      { symName = "smile"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8995"
      }
  , Sym
      { symName = "smt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10922"
      }
  , Sym
      { symName = "smt.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10924"
      }
  , Sym
      { symName = "som"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8384"
      }
  , Sym
      { symName = "space"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = " "
      }
  , Sym
      { symName = "space.nobreak"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\160"
      }
  , Sym
      { symName = "space.nobreak.narrow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8239"
      }
  , Sym
      { symName = "space.en"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8194"
      }
  , Sym
      { symName = "space.quad"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8195"
      }
  , Sym
      { symName = "space.third"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8196"
      }
  , Sym
      { symName = "space.quarter"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8197"
      }
  , Sym
      { symName = "space.sixth"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8198"
      }
  , Sym
      { symName = "space.med"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8287"
      }
  , Sym
      { symName = "space.fig"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8199"
      }
  , Sym
      { symName = "space.punct"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8200"
      }
  , Sym
      { symName = "space.thin"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8201"
      }
  , Sym
      { symName = "space.hair"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8202"
      }
  , Sym
      { symName = "spacebar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9251"
      }
  , Sym
      { symName = "square.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9633"
      }
  , Sym
      { symName = "square.stroked.tiny"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9643"
      }
  , Sym
      { symName = "square.stroked.small"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9725"
      }
  , Sym
      { symName = "square.stroked.medium"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9723"
      }
  , Sym
      { symName = "square.stroked.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11036"
      }
  , Sym
      { symName = "square.stroked.dotted"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11034"
      }
  , Sym
      { symName = "square.stroked.rounded"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9634"
      }
  , Sym
      { symName = "square.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9632"
      }
  , Sym
      { symName = "square.filled.tiny"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9642"
      }
  , Sym
      { symName = "square.filled.small"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9726"
      }
  , Sym
      { symName = "square.filled.medium"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9724"
      }
  , Sym
      { symName = "square.filled.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11035"
      }
  , Sym
      { symName = "star.op"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8902"
      }
  , Sym
      { symName = "star.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9734"
      }
  , Sym
      { symName = "star.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9733"
      }
  , Sym
      { symName = "subset"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8834"
      }
  , Sym
      { symName = "subset.approx"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10953"
      }
  , Sym
      { symName = "subset.closed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10959"
      }
  , Sym
      { symName = "subset.closed.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10961"
      }
  , Sym
      { symName = "subset.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10941"
      }
  , Sym
      { symName = "subset.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8912"
      }
  , Sym
      { symName = "subset.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8838"
      }
  , Sym
      { symName = "subset.eq.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10947"
      }
  , Sym
      { symName = "subset.eq.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8840"
      }
  , Sym
      { symName = "subset.eq.sq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8849"
      }
  , Sym
      { symName = "subset.eq.sq.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8930"
      }
  , Sym
      { symName = "subset.equiv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10949"
      }
  , Sym
      { symName = "subset.neq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8842"
      }
  , Sym
      { symName = "subset.nequiv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10955"
      }
  , Sym
      { symName = "subset.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8836"
      }
  , Sym
      { symName = "subset.plus"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10943"
      }
  , Sym
      { symName = "subset.sq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8847"
      }
  , Sym
      { symName = "subset.sq.neq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8932"
      }
  , Sym
      { symName = "subset.tilde"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10951"
      }
  , Sym
      { symName = "subset.times"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10945"
      }
  , Sym
      { symName = "succ"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8827"
      }
  , Sym
      { symName = "succ.approx"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10936"
      }
  , Sym
      { symName = "succ.curly.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8829"
      }
  , Sym
      { symName = "succ.curly.eq.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8929"
      }
  , Sym
      { symName = "succ.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10940"
      }
  , Sym
      { symName = "succ.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10928"
      }
  , Sym
      { symName = "succ.equiv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10932"
      }
  , Sym
      { symName = "succ.napprox"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10938"
      }
  , Sym
      { symName = "succ.neq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10930"
      }
  , Sym
      { symName = "succ.nequiv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10934"
      }
  , Sym
      { symName = "succ.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8833"
      }
  , Sym
      { symName = "succ.ntilde"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8937"
      }
  , Sym
      { symName = "succ.tilde"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8831"
      }
  , Sym
      { symName = "suit.club.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9827"
      }
  , Sym
      { symName = "suit.club.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9831"
      }
  , Sym
      { symName = "suit.diamond.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9830"
      }
  , Sym
      { symName = "suit.diamond.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9826"
      }
  , Sym
      { symName = "suit.heart.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9829"
      }
  , Sym
      { symName = "suit.heart.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9825"
      }
  , Sym
      { symName = "suit.spade.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9824"
      }
  , Sym
      { symName = "suit.spade.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9828"
      }
  , Sym
      { symName = "sum"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8721"
      }
  , Sym
      { symName = "sum.integral"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10763"
      }
  , Sym
      { symName = "sun"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9737"
      }
  , Sym
      { symName = "supset"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8835"
      }
  , Sym
      { symName = "supset.approx"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10954"
      }
  , Sym
      { symName = "supset.closed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10960"
      }
  , Sym
      { symName = "supset.closed.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10962"
      }
  , Sym
      { symName = "supset.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10942"
      }
  , Sym
      { symName = "supset.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8913"
      }
  , Sym
      { symName = "supset.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8839"
      }
  , Sym
      { symName = "supset.eq.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10948"
      }
  , Sym
      { symName = "supset.eq.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8841"
      }
  , Sym
      { symName = "supset.eq.sq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8850"
      }
  , Sym
      { symName = "supset.eq.sq.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8931"
      }
  , Sym
      { symName = "supset.equiv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10950"
      }
  , Sym
      { symName = "supset.neq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8843"
      }
  , Sym
      { symName = "supset.nequiv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10956"
      }
  , Sym
      { symName = "supset.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8837"
      }
  , Sym
      { symName = "supset.plus"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10944"
      }
  , Sym
      { symName = "supset.sq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8848"
      }
  , Sym
      { symName = "supset.sq.neq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8933"
      }
  , Sym
      { symName = "supset.tilde"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10952"
      }
  , Sym
      { symName = "supset.times"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10946"
      }
  , Sym
      { symName = "tack.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8866"
      }
  , Sym
      { symName = "tack.r.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8876"
      }
  , Sym
      { symName = "tack.r.long"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10205"
      }
  , Sym
      { symName = "tack.r.short"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8870"
      }
  , Sym
      { symName = "tack.r.double"
      , symIsAccent = False
      , symDeprecation =
          Just
            "`tack.double` is deprecated, use repeated letters instead, e.g., `tack.rr`"
      , symMathClass = Relation
      , symText = "\8872"
      }
  , Sym
      { symName = "tack.rr"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8872"
      }
  , Sym
      { symName = "tack.r.double.not"
      , symIsAccent = False
      , symDeprecation =
          Just
            "`tack.double` is deprecated, use repeated letters instead, e.g., `tack.rr.not`"
      , symMathClass = Relation
      , symText = "\8877"
      }
  , Sym
      { symName = "tack.rr.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8877"
      }
  , Sym
      { symName = "tack.rrr"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10978"
      }
  , Sym
      { symName = "tack.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8867"
      }
  , Sym
      { symName = "tack.l.long"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10206"
      }
  , Sym
      { symName = "tack.l.short"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10974"
      }
  , Sym
      { symName = "tack.l.double"
      , symIsAccent = False
      , symDeprecation =
          Just
            "`tack.double` is deprecated, use repeated letters instead, e.g., `tack.ll`"
      , symMathClass = Relation
      , symText = "\10980"
      }
  , Sym
      { symName = "tack.ll"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10980"
      }
  , Sym
      { symName = "tack.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8869"
      }
  , Sym
      { symName = "tack.t.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10200"
      }
  , Sym
      { symName = "tack.t.double"
      , symIsAccent = False
      , symDeprecation =
          Just
            "`tack.double` is deprecated, use repeated letters instead, e.g., `tack.tt`"
      , symMathClass = Relation
      , symText = "\10987"
      }
  , Sym
      { symName = "tack.tt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10987"
      }
  , Sym
      { symName = "tack.t.short"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10976"
      }
  , Sym
      { symName = "tack.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8868"
      }
  , Sym
      { symName = "tack.b.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10201"
      }
  , Sym
      { symName = "tack.b.double"
      , symIsAccent = False
      , symDeprecation =
          Just
            "`tack.double` is deprecated, use repeated letters instead, e.g., `tack.bb`"
      , symMathClass = Relation
      , symText = "\10986"
      }
  , Sym
      { symName = "tack.bb"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10986"
      }
  , Sym
      { symName = "tack.b.short"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10975"
      }
  , Sym
      { symName = "tack.l.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10203"
      }
  , Sym
      { symName = "taka"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\2547"
      }
  , Sym
      { symName = "taman"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\2047"
      }
  , Sym
      { symName = "tau"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\964"
      }
  , Sym
      { symName = "tenge"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8376"
      }
  , Sym
      { symName = "therefore"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8756"
      }
  , Sym
      { symName = "theta"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\952"
      }
  , Sym
      { symName = "theta.alt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\977"
      }
  , Sym
      { symName = "tilde.op"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8764"
      }
  , Sym
      { symName = "tilde.basic"
      , symIsAccent = True
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "~"
      }
  , Sym
      { symName = "tilde.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10858"
      }
  , Sym
      { symName = "tilde.eq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8771"
      }
  , Sym
      { symName = "tilde.eq.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8772"
      }
  , Sym
      { symName = "tilde.eq.rev"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8909"
      }
  , Sym
      { symName = "tilde.equiv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8773"
      }
  , Sym
      { symName = "tilde.equiv.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8775"
      }
  , Sym
      { symName = "tilde.nequiv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8774"
      }
  , Sym
      { symName = "tilde.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8769"
      }
  , Sym
      { symName = "tilde.rev"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8765"
      }
  , Sym
      { symName = "tilde.rev.equiv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8780"
      }
  , Sym
      { symName = "tilde.triple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8779"
      }
  , Sym
      { symName = "times"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\215"
      }
  , Sym
      { symName = "times.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10761"
      }
  , Sym
      { symName = "times.o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8855"
      }
  , Sym
      { symName = "times.o.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10804"
      }
  , Sym
      { symName = "times.o.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10805"
      }
  , Sym
      { symName = "times.o.hat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10806"
      }
  , Sym
      { symName = "times.o.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10754"
      }
  , Sym
      { symName = "times.div"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8903"
      }
  , Sym
      { symName = "times.three.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8907"
      }
  , Sym
      { symName = "times.three.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8908"
      }
  , Sym
      { symName = "times.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8905"
      }
  , Sym
      { symName = "times.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8906"
      }
  , Sym
      { symName = "times.square"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8864"
      }
  , Sym
      { symName = "times.triangle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10811"
      }
  , Sym
      { symName = "tiny"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10750"
      }
  , Sym
      { symName = "togrog"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8366"
      }
  , Sym
      { symName = "top"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8868"
      }
  , Sym
      { symName = "trademark"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8482"
      }
  , Sym
      { symName = "trademark.registered"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\174"
      }
  , Sym
      { symName = "trademark.service"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8480"
      }
  , Sym
      { symName = "triangle.stroked.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9651"
      }
  , Sym
      { symName = "triangle.stroked.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9661"
      }
  , Sym
      { symName = "triangle.stroked.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9655"
      }
  , Sym
      { symName = "triangle.stroked.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9665"
      }
  , Sym
      { symName = "triangle.stroked.bl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9722"
      }
  , Sym
      { symName = "triangle.stroked.br"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9727"
      }
  , Sym
      { symName = "triangle.stroked.tl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9720"
      }
  , Sym
      { symName = "triangle.stroked.tr"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9721"
      }
  , Sym
      { symName = "triangle.stroked.small.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9653"
      }
  , Sym
      { symName = "triangle.stroked.small.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9663"
      }
  , Sym
      { symName = "triangle.stroked.small.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9657"
      }
  , Sym
      { symName = "triangle.stroked.small.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9667"
      }
  , Sym
      { symName = "triangle.stroked.rounded"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128710"
      }
  , Sym
      { symName = "triangle.stroked.nested"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10177"
      }
  , Sym
      { symName = "triangle.stroked.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9708"
      }
  , Sym
      { symName = "triangle.filled.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9650"
      }
  , Sym
      { symName = "triangle.filled.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9660"
      }
  , Sym
      { symName = "triangle.filled.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9654"
      }
  , Sym
      { symName = "triangle.filled.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9664"
      }
  , Sym
      { symName = "triangle.filled.bl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9699"
      }
  , Sym
      { symName = "triangle.filled.br"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9698"
      }
  , Sym
      { symName = "triangle.filled.tl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9700"
      }
  , Sym
      { symName = "triangle.filled.tr"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9701"
      }
  , Sym
      { symName = "triangle.filled.small.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9652"
      }
  , Sym
      { symName = "triangle.filled.small.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9662"
      }
  , Sym
      { symName = "triangle.filled.small.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9656"
      }
  , Sym
      { symName = "triangle.filled.small.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9666"
      }
  , Sym
      { symName = "underscore"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "_"
      }
  , Sym
      { symName = "union"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8746"
      }
  , Sym
      { symName = "union.serif"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8746\65024"
      }
  , Sym
      { symName = "union.arrow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8844"
      }
  , Sym
      { symName = "union.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8899"
      }
  , Sym
      { symName = "union.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8845"
      }
  , Sym
      { symName = "union.dot.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10755"
      }
  , Sym
      { symName = "union.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8915"
      }
  , Sym
      { symName = "union.minus"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10817"
      }
  , Sym
      { symName = "union.or"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10821"
      }
  , Sym
      { symName = "union.plus"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8846"
      }
  , Sym
      { symName = "union.plus.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10756"
      }
  , Sym
      { symName = "union.sq"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8852"
      }
  , Sym
      { symName = "union.sq.serif"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8852\65024"
      }
  , Sym
      { symName = "union.sq.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10758"
      }
  , Sym
      { symName = "union.sq.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\10831"
      }
  , Sym
      { symName = "upsilon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\965"
      }
  , Sym
      { symName = "uranus"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9954"
      }
  , Sym
      { symName = "uranus.alt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9797"
      }
  , Sym
      { symName = "venus"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9792"
      }
  , Sym
      { symName = "without"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8726"
      }
  , Sym
      { symName = "wj"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8288"
      }
  , Sym
      { symName = "won"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8361"
      }
  , Sym
      { symName = "wreath"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8768"
      }
  , Sym
      { symName = "xi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\958"
      }
  , Sym
      { symName = "xor"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\8853"
      }
  , Sym
      { symName = "xor.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10753"
      }
  , Sym
      { symName = "yen"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\165"
      }
  , Sym
      { symName = "yuan"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\165"
      }
  , Sym
      { symName = "zero"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "0"
      }
  , Sym
      { symName = "zero.slashed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "0\65024"
      }
  , Sym
      { symName = "zeta"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Alphabetic
      , symText = "\950"
      }
  , Sym
      { symName = "zwj"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8205"
      }
  , Sym
      { symName = "zwnj"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8204"
      }
  , Sym
      { symName = "zws"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8203"
      }
  ]


-- | A list of triples, each consisting of the emoji name,
-- a Boolean indicating whether the symbol is an accent, and
-- the resolved emoji.
typstEmojis :: [Sym]
typstEmojis =

  [ Sym
      { symName = "ABCD"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128288"
      }
  , Sym
      { symName = "a"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127344"
      }
  , Sym
      { symName = "ab"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127374"
      }
  , Sym
      { symName = "abacus"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129518"
      }
  , Sym
      { symName = "abc"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128292"
      }
  , Sym
      { symName = "abcd"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128289"
      }
  , Sym
      { symName = "accordion"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129687"
      }
  , Sym
      { symName = "aesculapius"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9877"
      }
  , Sym
      { symName = "airplane"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9992"
      }
  , Sym
      { symName = "airplane.landing"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128748"
      }
  , Sym
      { symName = "airplane.small"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128745"
      }
  , Sym
      { symName = "airplane.takeoff"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128747"
      }
  , Sym
      { symName = "alembic"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9879"
      }
  , Sym
      { symName = "alien"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128125"
      }
  , Sym
      { symName = "alien.monster"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128126"
      }
  , Sym
      { symName = "ambulance"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128657"
      }
  , Sym
      { symName = "amphora"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127994"
      }
  , Sym
      { symName = "anchor"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9875"
      }
  , Sym
      { symName = "anger"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128162"
      }
  , Sym
      { symName = "ant"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128028"
      }
  , Sym
      { symName = "apple.green"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127823"
      }
  , Sym
      { symName = "apple.red"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127822"
      }
  , Sym
      { symName = "arm.mech"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129470"
      }
  , Sym
      { symName = "arm.muscle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128170"
      }
  , Sym
      { symName = "arm.selfie"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129331"
      }
  , Sym
      { symName = "arrow.r.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10145"
      }
  , Sym
      { symName = "arrow.r.hook"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8618"
      }
  , Sym
      { symName = "arrow.r.soon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128284"
      }
  , Sym
      { symName = "arrow.l.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11013"
      }
  , Sym
      { symName = "arrow.l.hook"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8617"
      }
  , Sym
      { symName = "arrow.l.back"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128281"
      }
  , Sym
      { symName = "arrow.l.end"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128282"
      }
  , Sym
      { symName = "arrow.t.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11014"
      }
  , Sym
      { symName = "arrow.t.curve"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10548"
      }
  , Sym
      { symName = "arrow.t.top"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128285"
      }
  , Sym
      { symName = "arrow.b.filled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\11015"
      }
  , Sym
      { symName = "arrow.b.curve"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\10549"
      }
  , Sym
      { symName = "arrow.l.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8596"
      }
  , Sym
      { symName = "arrow.l.r.on"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128283"
      }
  , Sym
      { symName = "arrow.t.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8597"
      }
  , Sym
      { symName = "arrow.bl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8601"
      }
  , Sym
      { symName = "arrow.br"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8600"
      }
  , Sym
      { symName = "arrow.tl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8598"
      }
  , Sym
      { symName = "arrow.tr"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Relation
      , symText = "\8599"
      }
  , Sym
      { symName = "arrows.cycle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128260"
      }
  , Sym
      { symName = "ast"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "*"
      }
  , Sym
      { symName = "ast.box"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10035"
      }
  , Sym
      { symName = "atm"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127975"
      }
  , Sym
      { symName = "atom"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9883"
      }
  , Sym
      { symName = "aubergine"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127814"
      }
  , Sym
      { symName = "avocado"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129361"
      }
  , Sym
      { symName = "axe"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129683"
      }
  , Sym
      { symName = "b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127345"
      }
  , Sym
      { symName = "baby"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128118"
      }
  , Sym
      { symName = "baby.angel"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128124"
      }
  , Sym
      { symName = "baby.box"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128700"
      }
  , Sym
      { symName = "babybottle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127868"
      }
  , Sym
      { symName = "backpack"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127890"
      }
  , Sym
      { symName = "bacon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129363"
      }
  , Sym
      { symName = "badger"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129441"
      }
  , Sym
      { symName = "badminton"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127992"
      }
  , Sym
      { symName = "bagel"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129391"
      }
  , Sym
      { symName = "baggageclaim"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128708"
      }
  , Sym
      { symName = "baguette"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129366"
      }
  , Sym
      { symName = "balloon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127880"
      }
  , Sym
      { symName = "ballot.check"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9745"
      }
  , Sym
      { symName = "ballotbox"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128499"
      }
  , Sym
      { symName = "banana"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127820"
      }
  , Sym
      { symName = "banjo"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129685"
      }
  , Sym
      { symName = "bank"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127974"
      }
  , Sym
      { symName = "barberpole"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128136"
      }
  , Sym
      { symName = "baseball"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9918"
      }
  , Sym
      { symName = "basecap"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129506"
      }
  , Sym
      { symName = "basket"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129530"
      }
  , Sym
      { symName = "basketball"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9977"
      }
  , Sym
      { symName = "basketball.ball"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127936"
      }
  , Sym
      { symName = "bat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129415"
      }
  , Sym
      { symName = "bathtub"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128704"
      }
  , Sym
      { symName = "bathtub.foam"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128705"
      }
  , Sym
      { symName = "battery"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128267"
      }
  , Sym
      { symName = "battery.low"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129707"
      }
  , Sym
      { symName = "beach.palm"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127965"
      }
  , Sym
      { symName = "beach.umbrella"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127958"
      }
  , Sym
      { symName = "beads"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128255"
      }
  , Sym
      { symName = "beans"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129752"
      }
  , Sym
      { symName = "bear"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128059"
      }
  , Sym
      { symName = "beaver"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129451"
      }
  , Sym
      { symName = "bed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128719"
      }
  , Sym
      { symName = "bed.person"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128716"
      }
  , Sym
      { symName = "bee"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128029"
      }
  , Sym
      { symName = "beer"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127866"
      }
  , Sym
      { symName = "beer.clink"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127867"
      }
  , Sym
      { symName = "beet"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129756"
      }
  , Sym
      { symName = "beetle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129714"
      }
  , Sym
      { symName = "beetle.lady"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128030"
      }
  , Sym
      { symName = "bell"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128276"
      }
  , Sym
      { symName = "bell.ding"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128718"
      }
  , Sym
      { symName = "bell.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128277"
      }
  , Sym
      { symName = "bento"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127857"
      }
  , Sym
      { symName = "bicyclist"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128692"
      }
  , Sym
      { symName = "bicyclist.mountain"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128693"
      }
  , Sym
      { symName = "bigfoot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129736"
      }
  , Sym
      { symName = "bike"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128690"
      }
  , Sym
      { symName = "bike.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128691"
      }
  , Sym
      { symName = "bikini"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128089"
      }
  , Sym
      { symName = "billiards"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127921"
      }
  , Sym
      { symName = "bin"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128465"
      }
  , Sym
      { symName = "biohazard"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9763"
      }
  , Sym
      { symName = "bird"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128038"
      }
  , Sym
      { symName = "bison"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129452"
      }
  , Sym
      { symName = "blood"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129656"
      }
  , Sym
      { symName = "blouse"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128090"
      }
  , Sym
      { symName = "blowfish"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128033"
      }
  , Sym
      { symName = "blueberries"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129744"
      }
  , Sym
      { symName = "boar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128023"
      }
  , Sym
      { symName = "boat.sail"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9973"
      }
  , Sym
      { symName = "boat.row"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128675"
      }
  , Sym
      { symName = "boat.motor"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128741"
      }
  , Sym
      { symName = "boat.speed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128676"
      }
  , Sym
      { symName = "boat.canoe"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128758"
      }
  , Sym
      { symName = "bolt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128297"
      }
  , Sym
      { symName = "bomb"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128163"
      }
  , Sym
      { symName = "bone"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129460"
      }
  , Sym
      { symName = "book.red"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128213"
      }
  , Sym
      { symName = "book.blue"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128216"
      }
  , Sym
      { symName = "book.green"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128215"
      }
  , Sym
      { symName = "book.orange"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128217"
      }
  , Sym
      { symName = "book.spiral"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128210"
      }
  , Sym
      { symName = "book.open"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128214"
      }
  , Sym
      { symName = "bookmark"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128278"
      }
  , Sym
      { symName = "books"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128218"
      }
  , Sym
      { symName = "boomerang"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129667"
      }
  , Sym
      { symName = "bordercontrol"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128706"
      }
  , Sym
      { symName = "bouquet"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128144"
      }
  , Sym
      { symName = "bow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127993"
      }
  , Sym
      { symName = "bowl.spoon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129379"
      }
  , Sym
      { symName = "bowl.steam"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127836"
      }
  , Sym
      { symName = "bowling"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127923"
      }
  , Sym
      { symName = "boxing"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129354"
      }
  , Sym
      { symName = "boy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128102"
      }
  , Sym
      { symName = "brain"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129504"
      }
  , Sym
      { symName = "bread"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127838"
      }
  , Sym
      { symName = "brick"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129521"
      }
  , Sym
      { symName = "bride"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128112"
      }
  , Sym
      { symName = "bridge.fog"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127745"
      }
  , Sym
      { symName = "bridge.night"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127753"
      }
  , Sym
      { symName = "briefcase"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128188"
      }
  , Sym
      { symName = "briefs"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129650"
      }
  , Sym
      { symName = "brightness.high"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128262"
      }
  , Sym
      { symName = "brightness.low"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128261"
      }
  , Sym
      { symName = "broccoli"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129382"
      }
  , Sym
      { symName = "broom"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129529"
      }
  , Sym
      { symName = "brush"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128396"
      }
  , Sym
      { symName = "bubble.speech.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128172"
      }
  , Sym
      { symName = "bubble.speech.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128488"
      }
  , Sym
      { symName = "bubble.thought"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128173"
      }
  , Sym
      { symName = "bubble.anger.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128495"
      }
  , Sym
      { symName = "bubbles"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129767"
      }
  , Sym
      { symName = "bubbletea"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129483"
      }
  , Sym
      { symName = "bucket"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129699"
      }
  , Sym
      { symName = "buffalo.water"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128003"
      }
  , Sym
      { symName = "bug"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128027"
      }
  , Sym
      { symName = "builder"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128119"
      }
  , Sym
      { symName = "burger"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127828"
      }
  , Sym
      { symName = "burrito"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127791"
      }
  , Sym
      { symName = "bus"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128652"
      }
  , Sym
      { symName = "bus.front"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128653"
      }
  , Sym
      { symName = "bus.small"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128656"
      }
  , Sym
      { symName = "bus.stop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128655"
      }
  , Sym
      { symName = "bus.trolley"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128654"
      }
  , Sym
      { symName = "butter"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129480"
      }
  , Sym
      { symName = "butterfly"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129419"
      }
  , Sym
      { symName = "button"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128306"
      }
  , Sym
      { symName = "button.alt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128307"
      }
  , Sym
      { symName = "button.radio"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128280"
      }
  , Sym
      { symName = "cabinet.file"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128452"
      }
  , Sym
      { symName = "cablecar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128672"
      }
  , Sym
      { symName = "cablecar.small"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128673"
      }
  , Sym
      { symName = "cactus"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127797"
      }
  , Sym
      { symName = "cake"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127874"
      }
  , Sym
      { symName = "cake.fish"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127845"
      }
  , Sym
      { symName = "cake.moon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129390"
      }
  , Sym
      { symName = "cake.slice"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127856"
      }
  , Sym
      { symName = "calendar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128197"
      }
  , Sym
      { symName = "calendar.spiral"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128467"
      }
  , Sym
      { symName = "calendar.tearoff"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128198"
      }
  , Sym
      { symName = "camel"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128043"
      }
  , Sym
      { symName = "camel.dromedar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128042"
      }
  , Sym
      { symName = "camera"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128247"
      }
  , Sym
      { symName = "camera.flash"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128248"
      }
  , Sym
      { symName = "camera.movie"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127909"
      }
  , Sym
      { symName = "camera.movie.box"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127910"
      }
  , Sym
      { symName = "camera.video"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128249"
      }
  , Sym
      { symName = "camping"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127957"
      }
  , Sym
      { symName = "can"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129387"
      }
  , Sym
      { symName = "candle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128367"
      }
  , Sym
      { symName = "candy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127852"
      }
  , Sym
      { symName = "cane"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129455"
      }
  , Sym
      { symName = "car"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128663"
      }
  , Sym
      { symName = "car.front"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128664"
      }
  , Sym
      { symName = "car.pickup"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128763"
      }
  , Sym
      { symName = "car.police"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128659"
      }
  , Sym
      { symName = "car.police.front"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128660"
      }
  , Sym
      { symName = "car.racing"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127950"
      }
  , Sym
      { symName = "car.rickshaw"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128762"
      }
  , Sym
      { symName = "car.suv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128665"
      }
  , Sym
      { symName = "card.credit"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128179"
      }
  , Sym
      { symName = "card.id"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129706"
      }
  , Sym
      { symName = "cardindex"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128199"
      }
  , Sym
      { symName = "carrot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129365"
      }
  , Sym
      { symName = "cart"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128722"
      }
  , Sym
      { symName = "cassette"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128252"
      }
  , Sym
      { symName = "castle.eu"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127984"
      }
  , Sym
      { symName = "castle.jp"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127983"
      }
  , Sym
      { symName = "cat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128008"
      }
  , Sym
      { symName = "cat.face"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128049"
      }
  , Sym
      { symName = "cat.face.angry"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128574"
      }
  , Sym
      { symName = "cat.face.cry"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128575"
      }
  , Sym
      { symName = "cat.face.heart"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128571"
      }
  , Sym
      { symName = "cat.face.joy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128569"
      }
  , Sym
      { symName = "cat.face.kiss"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128573"
      }
  , Sym
      { symName = "cat.face.laugh"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128568"
      }
  , Sym
      { symName = "cat.face.shock"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128576"
      }
  , Sym
      { symName = "cat.face.smile"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128570"
      }
  , Sym
      { symName = "cat.face.smirk"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128572"
      }
  , Sym
      { symName = "chain"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128279"
      }
  , Sym
      { symName = "chains"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9939"
      }
  , Sym
      { symName = "chair"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129681"
      }
  , Sym
      { symName = "champagne"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127870"
      }
  , Sym
      { symName = "chart.bar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128202"
      }
  , Sym
      { symName = "chart.up"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128200"
      }
  , Sym
      { symName = "chart.down"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128201"
      }
  , Sym
      { symName = "chart.yen.up"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128185"
      }
  , Sym
      { symName = "checkmark.heavy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10004"
      }
  , Sym
      { symName = "checkmark.box"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9989"
      }
  , Sym
      { symName = "cheese"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129472"
      }
  , Sym
      { symName = "cherries"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127826"
      }
  , Sym
      { symName = "chess"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9823"
      }
  , Sym
      { symName = "chestnut"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127792"
      }
  , Sym
      { symName = "chicken"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128020"
      }
  , Sym
      { symName = "chicken.baby"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128037"
      }
  , Sym
      { symName = "chicken.baby.egg"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128035"
      }
  , Sym
      { symName = "chicken.baby.head"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128036"
      }
  , Sym
      { symName = "chicken.leg"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127831"
      }
  , Sym
      { symName = "chicken.male"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128019"
      }
  , Sym
      { symName = "child"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129490"
      }
  , Sym
      { symName = "chipmunk"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128063"
      }
  , Sym
      { symName = "chocolate"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127851"
      }
  , Sym
      { symName = "chopsticks"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129378"
      }
  , Sym
      { symName = "church"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9962"
      }
  , Sym
      { symName = "church.love"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128146"
      }
  , Sym
      { symName = "cigarette"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128684"
      }
  , Sym
      { symName = "cigarette.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128685"
      }
  , Sym
      { symName = "circle.black"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9899"
      }
  , Sym
      { symName = "circle.blue"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128309"
      }
  , Sym
      { symName = "circle.brown"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128996"
      }
  , Sym
      { symName = "circle.green"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128994"
      }
  , Sym
      { symName = "circle.orange"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128992"
      }
  , Sym
      { symName = "circle.purple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128995"
      }
  , Sym
      { symName = "circle.white"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9898"
      }
  , Sym
      { symName = "circle.red"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128308"
      }
  , Sym
      { symName = "circle.yellow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128993"
      }
  , Sym
      { symName = "circle.stroked"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11093"
      }
  , Sym
      { symName = "circus"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127914"
      }
  , Sym
      { symName = "city"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127961"
      }
  , Sym
      { symName = "city.dusk"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127750"
      }
  , Sym
      { symName = "city.night"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127747"
      }
  , Sym
      { symName = "city.sunset"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127751"
      }
  , Sym
      { symName = "cl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127377"
      }
  , Sym
      { symName = "clamp"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128476"
      }
  , Sym
      { symName = "clapperboard"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127916"
      }
  , Sym
      { symName = "climbing"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129495"
      }
  , Sym
      { symName = "clip"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128206"
      }
  , Sym
      { symName = "clipboard"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128203"
      }
  , Sym
      { symName = "clips"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128391"
      }
  , Sym
      { symName = "clock.one"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128336"
      }
  , Sym
      { symName = "clock.one.thirty"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128348"
      }
  , Sym
      { symName = "clock.two"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128337"
      }
  , Sym
      { symName = "clock.two.thirty"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128349"
      }
  , Sym
      { symName = "clock.three"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128338"
      }
  , Sym
      { symName = "clock.three.thirty"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128350"
      }
  , Sym
      { symName = "clock.four"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128339"
      }
  , Sym
      { symName = "clock.four.thirty"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128351"
      }
  , Sym
      { symName = "clock.five"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128340"
      }
  , Sym
      { symName = "clock.five.thirty"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128352"
      }
  , Sym
      { symName = "clock.six"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128341"
      }
  , Sym
      { symName = "clock.six.thirty"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128353"
      }
  , Sym
      { symName = "clock.seven"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128342"
      }
  , Sym
      { symName = "clock.seven.thirty"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128354"
      }
  , Sym
      { symName = "clock.eight"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128343"
      }
  , Sym
      { symName = "clock.eight.thirty"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128355"
      }
  , Sym
      { symName = "clock.nine"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128344"
      }
  , Sym
      { symName = "clock.nine.thirty"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128356"
      }
  , Sym
      { symName = "clock.ten"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128345"
      }
  , Sym
      { symName = "clock.ten.thirty"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128357"
      }
  , Sym
      { symName = "clock.eleven"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128346"
      }
  , Sym
      { symName = "clock.eleven.thirty"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128358"
      }
  , Sym
      { symName = "clock.twelve"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128347"
      }
  , Sym
      { symName = "clock.twelve.thirty"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128359"
      }
  , Sym
      { symName = "clock.alarm"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9200"
      }
  , Sym
      { symName = "clock.old"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128368"
      }
  , Sym
      { symName = "clock.timer"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9202"
      }
  , Sym
      { symName = "cloud"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9729"
      }
  , Sym
      { symName = "cloud.dust"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128168"
      }
  , Sym
      { symName = "cloud.rain"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127783"
      }
  , Sym
      { symName = "cloud.snow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127784"
      }
  , Sym
      { symName = "cloud.storm"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9928"
      }
  , Sym
      { symName = "cloud.sun"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9925"
      }
  , Sym
      { symName = "cloud.sun.hidden"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127781"
      }
  , Sym
      { symName = "cloud.sun.rain"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127782"
      }
  , Sym
      { symName = "cloud.thunder"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127785"
      }
  , Sym
      { symName = "coat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129509"
      }
  , Sym
      { symName = "coat.lab"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129404"
      }
  , Sym
      { symName = "cockroach"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129715"
      }
  , Sym
      { symName = "cocktail.martini"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127864"
      }
  , Sym
      { symName = "cocktail.tropical"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127865"
      }
  , Sym
      { symName = "coconut"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129381"
      }
  , Sym
      { symName = "coffee"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9749"
      }
  , Sym
      { symName = "coffin"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9904"
      }
  , Sym
      { symName = "coin"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129689"
      }
  , Sym
      { symName = "comet"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9732"
      }
  , Sym
      { symName = "compass"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129517"
      }
  , Sym
      { symName = "computer"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128421"
      }
  , Sym
      { symName = "computermouse"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128433"
      }
  , Sym
      { symName = "confetti"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127882"
      }
  , Sym
      { symName = "construction"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128679"
      }
  , Sym
      { symName = "controller"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127918"
      }
  , Sym
      { symName = "cookie"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127850"
      }
  , Sym
      { symName = "cookie.fortune"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129376"
      }
  , Sym
      { symName = "cooking"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127859"
      }
  , Sym
      { symName = "cool"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127378"
      }
  , Sym
      { symName = "copyright"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\169"
      }
  , Sym
      { symName = "coral"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129720"
      }
  , Sym
      { symName = "corn"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127805"
      }
  , Sym
      { symName = "couch"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128715"
      }
  , Sym
      { symName = "couple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128145"
      }
  , Sym
      { symName = "cow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128004"
      }
  , Sym
      { symName = "cow.face"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128046"
      }
  , Sym
      { symName = "crab"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129408"
      }
  , Sym
      { symName = "crane"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127959"
      }
  , Sym
      { symName = "crayon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128397"
      }
  , Sym
      { symName = "cricket"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129431"
      }
  , Sym
      { symName = "cricketbat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127951"
      }
  , Sym
      { symName = "crocodile"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128010"
      }
  , Sym
      { symName = "croissant"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129360"
      }
  , Sym
      { symName = "crossmark"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10060"
      }
  , Sym
      { symName = "crossmark.box"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10062"
      }
  , Sym
      { symName = "crown"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128081"
      }
  , Sym
      { symName = "crutch"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129660"
      }
  , Sym
      { symName = "crystal"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128302"
      }
  , Sym
      { symName = "cucumber"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129362"
      }
  , Sym
      { symName = "cup.straw"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129380"
      }
  , Sym
      { symName = "cupcake"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129473"
      }
  , Sym
      { symName = "curling"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129356"
      }
  , Sym
      { symName = "curry"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127835"
      }
  , Sym
      { symName = "custard"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127854"
      }
  , Sym
      { symName = "customs"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128707"
      }
  , Sym
      { symName = "cutlery"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127860"
      }
  , Sym
      { symName = "cyclone"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127744"
      }
  , Sym
      { symName = "dancing.ballet"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129489\8205\129648"
      }
  , Sym
      { symName = "dancing.man"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128378"
      }
  , Sym
      { symName = "dancing.woman"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128131"
      }
  , Sym
      { symName = "dancing.bunny"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128111"
      }
  , Sym
      { symName = "dancing.bunny.men"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128111\8205\9794"
      }
  , Sym
      { symName = "dancing.bunny.women"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128111\8205\9792"
      }
  , Sym
      { symName = "darts"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127919"
      }
  , Sym
      { symName = "dash.wave.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\12336"
      }
  , Sym
      { symName = "deer"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129420"
      }
  , Sym
      { symName = "desert"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127964"
      }
  , Sym
      { symName = "detective"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128373"
      }
  , Sym
      { symName = "diamond.blue"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128311"
      }
  , Sym
      { symName = "diamond.blue.small"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128313"
      }
  , Sym
      { symName = "diamond.orange"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128310"
      }
  , Sym
      { symName = "diamond.orange.small"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128312"
      }
  , Sym
      { symName = "diamond.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128160"
      }
  , Sym
      { symName = "die"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127922"
      }
  , Sym
      { symName = "dino.pod"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129429"
      }
  , Sym
      { symName = "dino.rex"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129430"
      }
  , Sym
      { symName = "disc.cd"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128191"
      }
  , Sym
      { symName = "disc.dvd"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128192"
      }
  , Sym
      { symName = "disc.mini"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128189"
      }
  , Sym
      { symName = "discoball"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129705"
      }
  , Sym
      { symName = "diving"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129343"
      }
  , Sym
      { symName = "dodo"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129444"
      }
  , Sym
      { symName = "dog"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128021"
      }
  , Sym
      { symName = "dog.face"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128054"
      }
  , Sym
      { symName = "dog.guide"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129454"
      }
  , Sym
      { symName = "dog.poodle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128041"
      }
  , Sym
      { symName = "dollar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128178"
      }
  , Sym
      { symName = "dolphin"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128044"
      }
  , Sym
      { symName = "donkey"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129743"
      }
  , Sym
      { symName = "donut"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127849"
      }
  , Sym
      { symName = "door"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128682"
      }
  , Sym
      { symName = "dove.peace"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128330"
      }
  , Sym
      { symName = "dragon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128009"
      }
  , Sym
      { symName = "dragon.face"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128050"
      }
  , Sym
      { symName = "dress"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128087"
      }
  , Sym
      { symName = "dress.kimono"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128088"
      }
  , Sym
      { symName = "dress.sari"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129403"
      }
  , Sym
      { symName = "drop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128167"
      }
  , Sym
      { symName = "drops"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128166"
      }
  , Sym
      { symName = "drum"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129345"
      }
  , Sym
      { symName = "drum.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129688"
      }
  , Sym
      { symName = "duck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129414"
      }
  , Sym
      { symName = "dumpling"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129375"
      }
  , Sym
      { symName = "eagle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129413"
      }
  , Sym
      { symName = "ear"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128066"
      }
  , Sym
      { symName = "ear.aid"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129467"
      }
  , Sym
      { symName = "egg"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129370"
      }
  , Sym
      { symName = "eighteen.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128286"
      }
  , Sym
      { symName = "elephant"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128024"
      }
  , Sym
      { symName = "elevator"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128727"
      }
  , Sym
      { symName = "elf"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129501"
      }
  , Sym
      { symName = "email"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128231"
      }
  , Sym
      { symName = "excl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10071"
      }
  , Sym
      { symName = "excl.white"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10069"
      }
  , Sym
      { symName = "excl.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8252"
      }
  , Sym
      { symName = "excl.quest"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8265"
      }
  , Sym
      { symName = "explosion"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128165"
      }
  , Sym
      { symName = "extinguisher"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129519"
      }
  , Sym
      { symName = "eye"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128065"
      }
  , Sym
      { symName = "eyes"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128064"
      }
  , Sym
      { symName = "face.grin"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128512"
      }
  , Sym
      { symName = "face.angry"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128544"
      }
  , Sym
      { symName = "face.angry.red"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128545"
      }
  , Sym
      { symName = "face.anguish"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128551"
      }
  , Sym
      { symName = "face.astonish"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128562"
      }
  , Sym
      { symName = "face.bandage"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129301"
      }
  , Sym
      { symName = "face.beam"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128513"
      }
  , Sym
      { symName = "face.blank"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128566"
      }
  , Sym
      { symName = "face.clown"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129313"
      }
  , Sym
      { symName = "face.cold"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129398"
      }
  , Sym
      { symName = "face.concern"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128550"
      }
  , Sym
      { symName = "face.cool"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128526"
      }
  , Sym
      { symName = "face.cover"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129325"
      }
  , Sym
      { symName = "face.cowboy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129312"
      }
  , Sym
      { symName = "face.cry"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128557"
      }
  , Sym
      { symName = "face.devil.smile"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128520"
      }
  , Sym
      { symName = "face.devil.frown"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128127"
      }
  , Sym
      { symName = "face.diagonal"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129764"
      }
  , Sym
      { symName = "face.disguise"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129400"
      }
  , Sym
      { symName = "face.distorted"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129770"
      }
  , Sym
      { symName = "face.distress"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128555"
      }
  , Sym
      { symName = "face.dizzy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128565"
      }
  , Sym
      { symName = "face.dotted"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129765"
      }
  , Sym
      { symName = "face.down"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128542"
      }
  , Sym
      { symName = "face.down.sweat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128531"
      }
  , Sym
      { symName = "face.drool"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129316"
      }
  , Sym
      { symName = "face.explode"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129327"
      }
  , Sym
      { symName = "face.eyeroll"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128580"
      }
  , Sym
      { symName = "face.friendly"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9786"
      }
  , Sym
      { symName = "face.fear"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128552"
      }
  , Sym
      { symName = "face.fear.sweat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128560"
      }
  , Sym
      { symName = "face.fever"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129298"
      }
  , Sym
      { symName = "face.flush"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128563"
      }
  , Sym
      { symName = "face.frown"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9785"
      }
  , Sym
      { symName = "face.frown.slight"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128577"
      }
  , Sym
      { symName = "face.frust"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128547"
      }
  , Sym
      { symName = "face.goofy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129322"
      }
  , Sym
      { symName = "face.halo"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128519"
      }
  , Sym
      { symName = "face.happy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128522"
      }
  , Sym
      { symName = "face.heart"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128525"
      }
  , Sym
      { symName = "face.hearts"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129392"
      }
  , Sym
      { symName = "face.heat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129397"
      }
  , Sym
      { symName = "face.hug"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129303"
      }
  , Sym
      { symName = "face.inv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128579"
      }
  , Sym
      { symName = "face.joy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128514"
      }
  , Sym
      { symName = "face.kiss"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128535"
      }
  , Sym
      { symName = "face.kiss.smile"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128537"
      }
  , Sym
      { symName = "face.kiss.heart"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128536"
      }
  , Sym
      { symName = "face.kiss.blush"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128538"
      }
  , Sym
      { symName = "face.lick"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128523"
      }
  , Sym
      { symName = "face.lie"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129317"
      }
  , Sym
      { symName = "face.mask"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128567"
      }
  , Sym
      { symName = "face.meh"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128530"
      }
  , Sym
      { symName = "face.melt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129760"
      }
  , Sym
      { symName = "face.money"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129297"
      }
  , Sym
      { symName = "face.monocle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129488"
      }
  , Sym
      { symName = "face.nausea"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129314"
      }
  , Sym
      { symName = "face.nerd"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129299"
      }
  , Sym
      { symName = "face.neutral"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128528"
      }
  , Sym
      { symName = "face.open"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128515"
      }
  , Sym
      { symName = "face.party"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129395"
      }
  , Sym
      { symName = "face.peek"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129763"
      }
  , Sym
      { symName = "face.plead"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129402"
      }
  , Sym
      { symName = "face.relief"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128524"
      }
  , Sym
      { symName = "face.rofl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129315"
      }
  , Sym
      { symName = "face.sad"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128532"
      }
  , Sym
      { symName = "face.salute"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129761"
      }
  , Sym
      { symName = "face.shaking"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129768"
      }
  , Sym
      { symName = "face.shock"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128561"
      }
  , Sym
      { symName = "face.shush"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129323"
      }
  , Sym
      { symName = "face.skeptic"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129320"
      }
  , Sym
      { symName = "face.sleep"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128564"
      }
  , Sym
      { symName = "face.sleepy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128554"
      }
  , Sym
      { symName = "face.smile"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128516"
      }
  , Sym
      { symName = "face.smile.slight"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128578"
      }
  , Sym
      { symName = "face.smile.sweat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128517"
      }
  , Sym
      { symName = "face.smile.tear"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129394"
      }
  , Sym
      { symName = "face.smirk"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128527"
      }
  , Sym
      { symName = "face.sneeze"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129319"
      }
  , Sym
      { symName = "face.speak.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129762"
      }
  , Sym
      { symName = "face.squint"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128518"
      }
  , Sym
      { symName = "face.stars"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129321"
      }
  , Sym
      { symName = "face.straight"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128529"
      }
  , Sym
      { symName = "face.suffer"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128534"
      }
  , Sym
      { symName = "face.surprise"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128559"
      }
  , Sym
      { symName = "face.symbols"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129324"
      }
  , Sym
      { symName = "face.tear"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128546"
      }
  , Sym
      { symName = "face.tear.relief"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128549"
      }
  , Sym
      { symName = "face.tear.withheld"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129401"
      }
  , Sym
      { symName = "face.teeth"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128556"
      }
  , Sym
      { symName = "face.think"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129300"
      }
  , Sym
      { symName = "face.tired"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129769"
      }
  , Sym
      { symName = "face.tongue"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128539"
      }
  , Sym
      { symName = "face.tongue.squint"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128541"
      }
  , Sym
      { symName = "face.tongue.wink"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128540"
      }
  , Sym
      { symName = "face.triumph"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128548"
      }
  , Sym
      { symName = "face.unhappy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128533"
      }
  , Sym
      { symName = "face.vomit"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129326"
      }
  , Sym
      { symName = "face.weary"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128553"
      }
  , Sym
      { symName = "face.wink"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128521"
      }
  , Sym
      { symName = "face.woozy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129396"
      }
  , Sym
      { symName = "face.worry"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128543"
      }
  , Sym
      { symName = "face.wow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128558"
      }
  , Sym
      { symName = "face.yawn"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129393"
      }
  , Sym
      { symName = "face.zip"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129296"
      }
  , Sym
      { symName = "factory"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127981"
      }
  , Sym
      { symName = "fairy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129498"
      }
  , Sym
      { symName = "faith.christ"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10013"
      }
  , Sym
      { symName = "faith.dharma"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9784"
      }
  , Sym
      { symName = "faith.khanda"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129711"
      }
  , Sym
      { symName = "faith.islam"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9770"
      }
  , Sym
      { symName = "faith.judaism"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10017"
      }
  , Sym
      { symName = "faith.menorah"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128334"
      }
  , Sym
      { symName = "faith.om"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128329"
      }
  , Sym
      { symName = "faith.orthodox"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9766"
      }
  , Sym
      { symName = "faith.peace"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9774"
      }
  , Sym
      { symName = "faith.star.dot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128303"
      }
  , Sym
      { symName = "faith.worship"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128720"
      }
  , Sym
      { symName = "faith.yinyang"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9775"
      }
  , Sym
      { symName = "falafel"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129478"
      }
  , Sym
      { symName = "family"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128106"
      }
  , Sym
      { symName = "fax"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128224"
      }
  , Sym
      { symName = "feather"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129718"
      }
  , Sym
      { symName = "feeding.breast"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129329"
      }
  , Sym
      { symName = "fencing"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129338"
      }
  , Sym
      { symName = "ferriswheel"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127905"
      }
  , Sym
      { symName = "fightcloud"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129775"
      }
  , Sym
      { symName = "filebox"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128451"
      }
  , Sym
      { symName = "filedividers"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128450"
      }
  , Sym
      { symName = "film"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127902"
      }
  , Sym
      { symName = "finger.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128073"
      }
  , Sym
      { symName = "finger.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128072"
      }
  , Sym
      { symName = "finger.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128070"
      }
  , Sym
      { symName = "finger.t.alt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9757"
      }
  , Sym
      { symName = "finger.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128071"
      }
  , Sym
      { symName = "finger.front"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129781"
      }
  , Sym
      { symName = "finger.m"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128405"
      }
  , Sym
      { symName = "fingerprint"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129734"
      }
  , Sym
      { symName = "fingers.cross"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129310"
      }
  , Sym
      { symName = "fingers.pinch"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129292"
      }
  , Sym
      { symName = "fingers.snap"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129776"
      }
  , Sym
      { symName = "fire"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128293"
      }
  , Sym
      { symName = "firecracker"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129512"
      }
  , Sym
      { symName = "fireengine"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128658"
      }
  , Sym
      { symName = "fireworks"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127878"
      }
  , Sym
      { symName = "fish"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128031"
      }
  , Sym
      { symName = "fish.tropical"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128032"
      }
  , Sym
      { symName = "fishing"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127907"
      }
  , Sym
      { symName = "fist.front"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128074"
      }
  , Sym
      { symName = "fist.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129308"
      }
  , Sym
      { symName = "fist.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129307"
      }
  , Sym
      { symName = "fist.raised"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9994"
      }
  , Sym
      { symName = "flag.black"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127988"
      }
  , Sym
      { symName = "flag.white"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127987"
      }
  , Sym
      { symName = "flag.goal"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127937"
      }
  , Sym
      { symName = "flag.golf"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9971"
      }
  , Sym
      { symName = "flag.red"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128681"
      }
  , Sym
      { symName = "flags.jp.crossed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127884"
      }
  , Sym
      { symName = "flamingo"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129449"
      }
  , Sym
      { symName = "flashlight"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128294"
      }
  , Sym
      { symName = "flatbread"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129747"
      }
  , Sym
      { symName = "fleur"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9884"
      }
  , Sym
      { symName = "floppy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128190"
      }
  , Sym
      { symName = "flower.hibiscus"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127802"
      }
  , Sym
      { symName = "flower.hyacinth"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129723"
      }
  , Sym
      { symName = "flower.lotus"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129719"
      }
  , Sym
      { symName = "flower.pink"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127800"
      }
  , Sym
      { symName = "flower.rose"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127801"
      }
  , Sym
      { symName = "flower.sun"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127803"
      }
  , Sym
      { symName = "flower.tulip"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127799"
      }
  , Sym
      { symName = "flower.white"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128174"
      }
  , Sym
      { symName = "flower.wilted"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129344"
      }
  , Sym
      { symName = "flower.yellow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127804"
      }
  , Sym
      { symName = "flute"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129672"
      }
  , Sym
      { symName = "fly"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129712"
      }
  , Sym
      { symName = "fog"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127787"
      }
  , Sym
      { symName = "folder"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128193"
      }
  , Sym
      { symName = "folder.open"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128194"
      }
  , Sym
      { symName = "fondue"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129749"
      }
  , Sym
      { symName = "foot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129462"
      }
  , Sym
      { symName = "football"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9917"
      }
  , Sym
      { symName = "football.am"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127944"
      }
  , Sym
      { symName = "forex"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128177"
      }
  , Sym
      { symName = "fountain"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9970"
      }
  , Sym
      { symName = "fox"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129418"
      }
  , Sym
      { symName = "free"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127379"
      }
  , Sym
      { symName = "fries"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127839"
      }
  , Sym
      { symName = "frisbee"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129359"
      }
  , Sym
      { symName = "frog.face"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128056"
      }
  , Sym
      { symName = "fuelpump"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9981"
      }
  , Sym
      { symName = "gachi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127543"
      }
  , Sym
      { symName = "garlic"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129476"
      }
  , Sym
      { symName = "gear"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9881"
      }
  , Sym
      { symName = "gem"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128142"
      }
  , Sym
      { symName = "genie"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129502"
      }
  , Sym
      { symName = "ghost"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128123"
      }
  , Sym
      { symName = "ginger"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129754"
      }
  , Sym
      { symName = "giraffe"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129426"
      }
  , Sym
      { symName = "girl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128103"
      }
  , Sym
      { symName = "glass.clink"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129346"
      }
  , Sym
      { symName = "glass.milk"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129371"
      }
  , Sym
      { symName = "glass.pour"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129751"
      }
  , Sym
      { symName = "glass.tumbler"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129347"
      }
  , Sym
      { symName = "glasses"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128083"
      }
  , Sym
      { symName = "glasses.sun"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128374"
      }
  , Sym
      { symName = "globe.am"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127758"
      }
  , Sym
      { symName = "globe.as.au"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127759"
      }
  , Sym
      { symName = "globe.eu.af"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127757"
      }
  , Sym
      { symName = "globe.meridian"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127760"
      }
  , Sym
      { symName = "gloves"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129508"
      }
  , Sym
      { symName = "go"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127540"
      }
  , Sym
      { symName = "goal"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129349"
      }
  , Sym
      { symName = "goat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128016"
      }
  , Sym
      { symName = "goggles"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129405"
      }
  , Sym
      { symName = "golfing"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127948"
      }
  , Sym
      { symName = "goose"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129727"
      }
  , Sym
      { symName = "gorilla"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129421"
      }
  , Sym
      { symName = "grapes"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127815"
      }
  , Sym
      { symName = "guard.man"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128130"
      }
  , Sym
      { symName = "guitar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127928"
      }
  , Sym
      { symName = "gymnastics"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129336"
      }
  , Sym
      { symName = "haircut"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128135"
      }
  , Sym
      { symName = "hairpick"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129710"
      }
  , Sym
      { symName = "hammer"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128296"
      }
  , Sym
      { symName = "hammer.pick"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9874"
      }
  , Sym
      { symName = "hammer.wrench"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128736"
      }
  , Sym
      { symName = "hamsa"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129708"
      }
  , Sym
      { symName = "hamster.face"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128057"
      }
  , Sym
      { symName = "hand.raised"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9995"
      }
  , Sym
      { symName = "hand.raised.alt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129306"
      }
  , Sym
      { symName = "hand.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129777"
      }
  , Sym
      { symName = "hand.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129778"
      }
  , Sym
      { symName = "hand.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129780"
      }
  , Sym
      { symName = "hand.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129779"
      }
  , Sym
      { symName = "hand.ok"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128076"
      }
  , Sym
      { symName = "hand.call"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129305"
      }
  , Sym
      { symName = "hand.love"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129311"
      }
  , Sym
      { symName = "hand.part"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128406"
      }
  , Sym
      { symName = "hand.peace"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9996"
      }
  , Sym
      { symName = "hand.pinch"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129295"
      }
  , Sym
      { symName = "hand.pushing.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129783"
      }
  , Sym
      { symName = "hand.pushing.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129784"
      }
  , Sym
      { symName = "hand.rock"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129304"
      }
  , Sym
      { symName = "hand.splay"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128400"
      }
  , Sym
      { symName = "hand.wave"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128075"
      }
  , Sym
      { symName = "hand.write"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9997"
      }
  , Sym
      { symName = "handbag"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128092"
      }
  , Sym
      { symName = "handball"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129342"
      }
  , Sym
      { symName = "handfan"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129709"
      }
  , Sym
      { symName = "handholding"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129489\8205\129309\8205\129489"
      }
  , Sym
      { symName = "handholding.man.man"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128108"
      }
  , Sym
      { symName = "handholding.woman.man"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128107"
      }
  , Sym
      { symName = "handholding.woman.woman"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128109"
      }
  , Sym
      { symName = "hands.folded"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128591"
      }
  , Sym
      { symName = "hands.palms"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129330"
      }
  , Sym
      { symName = "hands.clap"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128079"
      }
  , Sym
      { symName = "hands.heart"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129782"
      }
  , Sym
      { symName = "hands.open"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128080"
      }
  , Sym
      { symName = "hands.raised"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128588"
      }
  , Sym
      { symName = "hands.shake"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129309"
      }
  , Sym
      { symName = "harp"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129673"
      }
  , Sym
      { symName = "hash"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "#"
      }
  , Sym
      { symName = "hat.ribbon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128082"
      }
  , Sym
      { symName = "hat.top"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127913"
      }
  , Sym
      { symName = "headphone"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127911"
      }
  , Sym
      { symName = "heart"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10084"
      }
  , Sym
      { symName = "heart.arrow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128152"
      }
  , Sym
      { symName = "heart.beat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128147"
      }
  , Sym
      { symName = "heart.black"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128420"
      }
  , Sym
      { symName = "heart.blue"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128153"
      }
  , Sym
      { symName = "heart.box"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128159"
      }
  , Sym
      { symName = "heart.broken"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128148"
      }
  , Sym
      { symName = "heart.brown"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129294"
      }
  , Sym
      { symName = "heart.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128149"
      }
  , Sym
      { symName = "heart.excl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10083"
      }
  , Sym
      { symName = "heart.gray"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129654"
      }
  , Sym
      { symName = "heart.green"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128154"
      }
  , Sym
      { symName = "heart.grow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128151"
      }
  , Sym
      { symName = "heart.lightblue"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129653"
      }
  , Sym
      { symName = "heart.orange"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129505"
      }
  , Sym
      { symName = "heart.pink"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129655"
      }
  , Sym
      { symName = "heart.purple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128156"
      }
  , Sym
      { symName = "heart.real"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129728"
      }
  , Sym
      { symName = "heart.revolve"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128158"
      }
  , Sym
      { symName = "heart.ribbon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128157"
      }
  , Sym
      { symName = "heart.spark"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128150"
      }
  , Sym
      { symName = "heart.white"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129293"
      }
  , Sym
      { symName = "heart.yellow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128155"
      }
  , Sym
      { symName = "hedgehog"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129428"
      }
  , Sym
      { symName = "helicopter"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128641"
      }
  , Sym
      { symName = "helix"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129516"
      }
  , Sym
      { symName = "helmet.cross"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9937"
      }
  , Sym
      { symName = "helmet.military"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129686"
      }
  , Sym
      { symName = "hi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\12953"
      }
  , Sym
      { symName = "hippo"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129435"
      }
  , Sym
      { symName = "hockey"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127953"
      }
  , Sym
      { symName = "hole"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128371"
      }
  , Sym
      { symName = "honey"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127855"
      }
  , Sym
      { symName = "hongbao"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129511"
      }
  , Sym
      { symName = "hook"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129693"
      }
  , Sym
      { symName = "horn.postal"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128239"
      }
  , Sym
      { symName = "horse"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128014"
      }
  , Sym
      { symName = "horse.carousel"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127904"
      }
  , Sym
      { symName = "horse.face"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128052"
      }
  , Sym
      { symName = "horse.race"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127943"
      }
  , Sym
      { symName = "hospital"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127973"
      }
  , Sym
      { symName = "hotdog"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127789"
      }
  , Sym
      { symName = "hotel"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127976"
      }
  , Sym
      { symName = "hotel.love"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127977"
      }
  , Sym
      { symName = "hotspring"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9832"
      }
  , Sym
      { symName = "hourglass"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8987"
      }
  , Sym
      { symName = "hourglass.flow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9203"
      }
  , Sym
      { symName = "house"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127968"
      }
  , Sym
      { symName = "house.derelict"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127962"
      }
  , Sym
      { symName = "house.garden"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127969"
      }
  , Sym
      { symName = "house.multiple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127960"
      }
  , Sym
      { symName = "hundred"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128175"
      }
  , Sym
      { symName = "hut"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128726"
      }
  , Sym
      { symName = "ice"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129482"
      }
  , Sym
      { symName = "icecream"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127848"
      }
  , Sym
      { symName = "icecream.shaved"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127847"
      }
  , Sym
      { symName = "icecream.soft"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127846"
      }
  , Sym
      { symName = "icehockey"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127954"
      }
  , Sym
      { symName = "id"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127380"
      }
  , Sym
      { symName = "info"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8505"
      }
  , Sym
      { symName = "izakaya"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127982"
      }
  , Sym
      { symName = "jar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129753"
      }
  , Sym
      { symName = "jeans"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128086"
      }
  , Sym
      { symName = "jellyfish"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129724"
      }
  , Sym
      { symName = "jigsaw"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129513"
      }
  , Sym
      { symName = "joystick"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128377"
      }
  , Sym
      { symName = "juggling"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129337"
      }
  , Sym
      { symName = "juice"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129475"
      }
  , Sym
      { symName = "ka"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127569"
      }
  , Sym
      { symName = "kaaba"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128331"
      }
  , Sym
      { symName = "kachi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127545"
      }
  , Sym
      { symName = "kadomatsu"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127885"
      }
  , Sym
      { symName = "kangaroo"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129432"
      }
  , Sym
      { symName = "kara"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127539"
      }
  , Sym
      { symName = "kebab"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129369"
      }
  , Sym
      { symName = "key"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128273"
      }
  , Sym
      { symName = "key.old"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128477"
      }
  , Sym
      { symName = "keyboard"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9000"
      }
  , Sym
      { symName = "kiss"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128143"
      }
  , Sym
      { symName = "kissmark"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128139"
      }
  , Sym
      { symName = "kite"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129665"
      }
  , Sym
      { symName = "kiwi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129373"
      }
  , Sym
      { symName = "knife"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128298"
      }
  , Sym
      { symName = "knife.dagger"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128481"
      }
  , Sym
      { symName = "knot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129698"
      }
  , Sym
      { symName = "koala"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128040"
      }
  , Sym
      { symName = "koinobori"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127887"
      }
  , Sym
      { symName = "koko"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127489"
      }
  , Sym
      { symName = "kon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127538"
      }
  , Sym
      { symName = "label"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127991"
      }
  , Sym
      { symName = "lacrosse"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129357"
      }
  , Sym
      { symName = "ladder"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129692"
      }
  , Sym
      { symName = "lamp.diya"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129684"
      }
  , Sym
      { symName = "landslide"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128728"
      }
  , Sym
      { symName = "laptop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128187"
      }
  , Sym
      { symName = "leaf.clover.three"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9752"
      }
  , Sym
      { symName = "leaf.clover.four"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127808"
      }
  , Sym
      { symName = "leaf.fall"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127810"
      }
  , Sym
      { symName = "leaf.herb"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127807"
      }
  , Sym
      { symName = "leaf.maple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127809"
      }
  , Sym
      { symName = "leaf.wind"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127811"
      }
  , Sym
      { symName = "leftluggage"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128709"
      }
  , Sym
      { symName = "leg"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129461"
      }
  , Sym
      { symName = "leg.mech"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129471"
      }
  , Sym
      { symName = "lemon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127819"
      }
  , Sym
      { symName = "leopard"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128006"
      }
  , Sym
      { symName = "letter.love"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128140"
      }
  , Sym
      { symName = "liberty"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128509"
      }
  , Sym
      { symName = "lightbulb"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128161"
      }
  , Sym
      { symName = "lightning"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9889"
      }
  , Sym
      { symName = "lion"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129409"
      }
  , Sym
      { symName = "lipstick"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128132"
      }
  , Sym
      { symName = "litter"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128686"
      }
  , Sym
      { symName = "litter.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128687"
      }
  , Sym
      { symName = "lizard"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129422"
      }
  , Sym
      { symName = "llama"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129433"
      }
  , Sym
      { symName = "lobster"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129438"
      }
  , Sym
      { symName = "lock"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128274"
      }
  , Sym
      { symName = "lock.key"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128272"
      }
  , Sym
      { symName = "lock.open"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128275"
      }
  , Sym
      { symName = "lock.pen"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128271"
      }
  , Sym
      { symName = "lollipop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127853"
      }
  , Sym
      { symName = "lotion"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129524"
      }
  , Sym
      { symName = "luggage"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129523"
      }
  , Sym
      { symName = "lungs"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129729"
      }
  , Sym
      { symName = "mage"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129497"
      }
  , Sym
      { symName = "magnet"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129522"
      }
  , Sym
      { symName = "magnify.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128270"
      }
  , Sym
      { symName = "magnify.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128269"
      }
  , Sym
      { symName = "mahjong.dragon.red"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\126980"
      }
  , Sym
      { symName = "mail"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9993"
      }
  , Sym
      { symName = "mail.arrow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128233"
      }
  , Sym
      { symName = "mailbox.closed.empty"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128234"
      }
  , Sym
      { symName = "mailbox.closed.full"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128235"
      }
  , Sym
      { symName = "mailbox.open.empty"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128237"
      }
  , Sym
      { symName = "mailbox.open.full"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128236"
      }
  , Sym
      { symName = "mammoth"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129443"
      }
  , Sym
      { symName = "man"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128104"
      }
  , Sym
      { symName = "man.box"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128697"
      }
  , Sym
      { symName = "man.crown"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129332"
      }
  , Sym
      { symName = "man.guapimao"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128114"
      }
  , Sym
      { symName = "man.levitate"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128372"
      }
  , Sym
      { symName = "man.old"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128116"
      }
  , Sym
      { symName = "man.pregnant"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129731"
      }
  , Sym
      { symName = "man.turban"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128115"
      }
  , Sym
      { symName = "man.tuxedo"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129333"
      }
  , Sym
      { symName = "mango"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129389"
      }
  , Sym
      { symName = "map.world"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128506"
      }
  , Sym
      { symName = "map.jp"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128510"
      }
  , Sym
      { symName = "maracas"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129671"
      }
  , Sym
      { symName = "martialarts"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129355"
      }
  , Sym
      { symName = "masks"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127917"
      }
  , Sym
      { symName = "mate"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129481"
      }
  , Sym
      { symName = "matryoshka"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129670"
      }
  , Sym
      { symName = "meat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129385"
      }
  , Sym
      { symName = "meat.bone"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127830"
      }
  , Sym
      { symName = "medal.first"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129351"
      }
  , Sym
      { symName = "medal.second"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129352"
      }
  , Sym
      { symName = "medal.third"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129353"
      }
  , Sym
      { symName = "medal.sports"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127941"
      }
  , Sym
      { symName = "medal.military"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127894"
      }
  , Sym
      { symName = "megaphone"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128226"
      }
  , Sym
      { symName = "megaphone.simple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128227"
      }
  , Sym
      { symName = "melon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127816"
      }
  , Sym
      { symName = "merperson"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129500"
      }
  , Sym
      { symName = "metro"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9410"
      }
  , Sym
      { symName = "microbe"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129440"
      }
  , Sym
      { symName = "microphone"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127908"
      }
  , Sym
      { symName = "microphone.studio"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127897"
      }
  , Sym
      { symName = "microscope"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128300"
      }
  , Sym
      { symName = "milkyway"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127756"
      }
  , Sym
      { symName = "mirror"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129694"
      }
  , Sym
      { symName = "mixer"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127899"
      }
  , Sym
      { symName = "money.bag"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128176"
      }
  , Sym
      { symName = "money.dollar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128181"
      }
  , Sym
      { symName = "money.euro"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128182"
      }
  , Sym
      { symName = "money.pound"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128183"
      }
  , Sym
      { symName = "money.yen"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128180"
      }
  , Sym
      { symName = "money.wings"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128184"
      }
  , Sym
      { symName = "monkey"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128018"
      }
  , Sym
      { symName = "monkey.face"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128053"
      }
  , Sym
      { symName = "monkey.hear.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128585"
      }
  , Sym
      { symName = "monkey.see.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128584"
      }
  , Sym
      { symName = "monkey.speak.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128586"
      }
  , Sym
      { symName = "moon.crescent"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127769"
      }
  , Sym
      { symName = "moon.full"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127765"
      }
  , Sym
      { symName = "moon.full.face"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127773"
      }
  , Sym
      { symName = "moon.new"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127761"
      }
  , Sym
      { symName = "moon.new.face"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127770"
      }
  , Sym
      { symName = "moon.wane.one"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127766"
      }
  , Sym
      { symName = "moon.wane.two"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127767"
      }
  , Sym
      { symName = "moon.wane.three.face"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127772"
      }
  , Sym
      { symName = "moon.wane.three"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127768"
      }
  , Sym
      { symName = "moon.wax.one"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127762"
      }
  , Sym
      { symName = "moon.wax.two"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127763"
      }
  , Sym
      { symName = "moon.wax.two.face"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127771"
      }
  , Sym
      { symName = "moon.wax.three"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127764"
      }
  , Sym
      { symName = "moose"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129742"
      }
  , Sym
      { symName = "mortarboard"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127891"
      }
  , Sym
      { symName = "mosque"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128332"
      }
  , Sym
      { symName = "mosquito"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129439"
      }
  , Sym
      { symName = "motorcycle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127949"
      }
  , Sym
      { symName = "motorway"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128739"
      }
  , Sym
      { symName = "mountain"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9968"
      }
  , Sym
      { symName = "mountain.fuji"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128507"
      }
  , Sym
      { symName = "mountain.snow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127956"
      }
  , Sym
      { symName = "mountain.sunrise"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127748"
      }
  , Sym
      { symName = "mouse"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128001"
      }
  , Sym
      { symName = "mouse.face"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128045"
      }
  , Sym
      { symName = "mousetrap"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129700"
      }
  , Sym
      { symName = "mouth"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128068"
      }
  , Sym
      { symName = "mouth.bite"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129766"
      }
  , Sym
      { symName = "moyai"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128511"
      }
  , Sym
      { symName = "muryo"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127514"
      }
  , Sym
      { symName = "museum"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127963"
      }
  , Sym
      { symName = "mushroom"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127812"
      }
  , Sym
      { symName = "musicalscore"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127932"
      }
  , Sym
      { symName = "nails.polish"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128133"
      }
  , Sym
      { symName = "namebadge"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128219"
      }
  , Sym
      { symName = "nazar"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129535"
      }
  , Sym
      { symName = "necktie"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128084"
      }
  , Sym
      { symName = "needle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129697"
      }
  , Sym
      { symName = "nest.empty"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129721"
      }
  , Sym
      { symName = "nest.eggs"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129722"
      }
  , Sym
      { symName = "new"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127381"
      }
  , Sym
      { symName = "newspaper"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128240"
      }
  , Sym
      { symName = "newspaper.rolled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128478"
      }
  , Sym
      { symName = "ng"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127382"
      }
  , Sym
      { symName = "ningyo"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127886"
      }
  , Sym
      { symName = "ninja"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129399"
      }
  , Sym
      { symName = "noentry"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9940"
      }
  , Sym
      { symName = "nose"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128067"
      }
  , Sym
      { symName = "notebook"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128211"
      }
  , Sym
      { symName = "notebook.deco"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128212"
      }
  , Sym
      { symName = "notepad"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128466"
      }
  , Sym
      { symName = "notes"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127925"
      }
  , Sym
      { symName = "notes.triple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127926"
      }
  , Sym
      { symName = "numbers"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128290"
      }
  , Sym
      { symName = "o"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127358"
      }
  , Sym
      { symName = "octopus"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128025"
      }
  , Sym
      { symName = "office"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127970"
      }
  , Sym
      { symName = "oil"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128738"
      }
  , Sym
      { symName = "ok"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127383"
      }
  , Sym
      { symName = "olive"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129746"
      }
  , Sym
      { symName = "oni"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128121"
      }
  , Sym
      { symName = "onion"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129477"
      }
  , Sym
      { symName = "orangutan"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129447"
      }
  , Sym
      { symName = "orca"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129741"
      }
  , Sym
      { symName = "otter"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129446"
      }
  , Sym
      { symName = "owl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129417"
      }
  , Sym
      { symName = "ox"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128002"
      }
  , Sym
      { symName = "oyster"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129450"
      }
  , Sym
      { symName = "package"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128230"
      }
  , Sym
      { symName = "paella"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129368"
      }
  , Sym
      { symName = "page"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128196"
      }
  , Sym
      { symName = "page.curl"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128195"
      }
  , Sym
      { symName = "page.pencil"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128221"
      }
  , Sym
      { symName = "pager"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128223"
      }
  , Sym
      { symName = "pages.tabs"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128209"
      }
  , Sym
      { symName = "painting"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128444"
      }
  , Sym
      { symName = "palette"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127912"
      }
  , Sym
      { symName = "pancakes"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129374"
      }
  , Sym
      { symName = "panda"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128060"
      }
  , Sym
      { symName = "parachute"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129666"
      }
  , Sym
      { symName = "park"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127966"
      }
  , Sym
      { symName = "parking"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127359"
      }
  , Sym
      { symName = "parrot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129436"
      }
  , Sym
      { symName = "partalteration"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\12349"
      }
  , Sym
      { symName = "party"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127881"
      }
  , Sym
      { symName = "peach"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127825"
      }
  , Sym
      { symName = "peacock"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129434"
      }
  , Sym
      { symName = "peanuts"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129372"
      }
  , Sym
      { symName = "peapod"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129755"
      }
  , Sym
      { symName = "pear"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127824"
      }
  , Sym
      { symName = "pedestrian"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128694"
      }
  , Sym
      { symName = "pedestrian.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128695"
      }
  , Sym
      { symName = "pen.ball"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128394"
      }
  , Sym
      { symName = "pen.fountain"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128395"
      }
  , Sym
      { symName = "pencil"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9999"
      }
  , Sym
      { symName = "penguin"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128039"
      }
  , Sym
      { symName = "pepper"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129745"
      }
  , Sym
      { symName = "pepper.hot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127798"
      }
  , Sym
      { symName = "person"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129489"
      }
  , Sym
      { symName = "person.angry"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128590"
      }
  , Sym
      { symName = "person.beard"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129492"
      }
  , Sym
      { symName = "person.blonde"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128113"
      }
  , Sym
      { symName = "person.bow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128583"
      }
  , Sym
      { symName = "person.crown"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129733"
      }
  , Sym
      { symName = "person.deaf"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129487"
      }
  , Sym
      { symName = "person.facepalm"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129318"
      }
  , Sym
      { symName = "person.frown"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128589"
      }
  , Sym
      { symName = "person.hijab"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129493"
      }
  , Sym
      { symName = "person.kneel"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129486"
      }
  , Sym
      { symName = "person.lotus"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129496"
      }
  , Sym
      { symName = "person.massage"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128134"
      }
  , Sym
      { symName = "person.no"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128581"
      }
  , Sym
      { symName = "person.ok"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128582"
      }
  , Sym
      { symName = "person.old"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129491"
      }
  , Sym
      { symName = "person.pregnant"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129732"
      }
  , Sym
      { symName = "person.raise"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128587"
      }
  , Sym
      { symName = "person.sassy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128129"
      }
  , Sym
      { symName = "person.shrug"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129335"
      }
  , Sym
      { symName = "person.stand"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129485"
      }
  , Sym
      { symName = "person.steam"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129494"
      }
  , Sym
      { symName = "petri"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129515"
      }
  , Sym
      { symName = "phone"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128241"
      }
  , Sym
      { symName = "phone.arrow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128242"
      }
  , Sym
      { symName = "phone.classic"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9742"
      }
  , Sym
      { symName = "phone.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128245"
      }
  , Sym
      { symName = "phone.off"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128244"
      }
  , Sym
      { symName = "phone.receiver"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128222"
      }
  , Sym
      { symName = "phone.signal"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128246"
      }
  , Sym
      { symName = "phone.vibrate"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128243"
      }
  , Sym
      { symName = "piano"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127929"
      }
  , Sym
      { symName = "pick"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9935"
      }
  , Sym
      { symName = "pie"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129383"
      }
  , Sym
      { symName = "pig"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128022"
      }
  , Sym
      { symName = "pig.face"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128055"
      }
  , Sym
      { symName = "pig.nose"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128061"
      }
  , Sym
      { symName = "pill"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128138"
      }
  , Sym
      { symName = "pin"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128204"
      }
  , Sym
      { symName = "pin.round"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128205"
      }
  , Sym
      { symName = "pinata"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129669"
      }
  , Sym
      { symName = "pineapple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127821"
      }
  , Sym
      { symName = "pingpong"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127955"
      }
  , Sym
      { symName = "pistol"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128299"
      }
  , Sym
      { symName = "pizza"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127829"
      }
  , Sym
      { symName = "placard"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129703"
      }
  , Sym
      { symName = "planet"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129680"
      }
  , Sym
      { symName = "plant"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129716"
      }
  , Sym
      { symName = "plaster"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129657"
      }
  , Sym
      { symName = "plate.cutlery"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127869"
      }
  , Sym
      { symName = "playback.down"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9196"
      }
  , Sym
      { symName = "playback.eject"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9167"
      }
  , Sym
      { symName = "playback.forward"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9193"
      }
  , Sym
      { symName = "playback.pause"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9208"
      }
  , Sym
      { symName = "playback.record"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9210"
      }
  , Sym
      { symName = "playback.repeat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128257"
      }
  , Sym
      { symName = "playback.repeat.once"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128258"
      }
  , Sym
      { symName = "playback.repeat.v"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128259"
      }
  , Sym
      { symName = "playback.restart"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9198"
      }
  , Sym
      { symName = "playback.rewind"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9194"
      }
  , Sym
      { symName = "playback.shuffle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128256"
      }
  , Sym
      { symName = "playback.skip"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9197"
      }
  , Sym
      { symName = "playback.stop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9209"
      }
  , Sym
      { symName = "playback.toggle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9199"
      }
  , Sym
      { symName = "playback.up"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9195"
      }
  , Sym
      { symName = "playingcard.flower"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127924"
      }
  , Sym
      { symName = "playingcard.joker"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127183"
      }
  , Sym
      { symName = "plunger"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129696"
      }
  , Sym
      { symName = "policeofficer"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128110"
      }
  , Sym
      { symName = "poo"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128169"
      }
  , Sym
      { symName = "popcorn"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127871"
      }
  , Sym
      { symName = "post.eu"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127972"
      }
  , Sym
      { symName = "post.jp"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127971"
      }
  , Sym
      { symName = "postbox"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128238"
      }
  , Sym
      { symName = "potato"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129364"
      }
  , Sym
      { symName = "potato.sweet"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127840"
      }
  , Sym
      { symName = "pouch"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128093"
      }
  , Sym
      { symName = "powerplug"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128268"
      }
  , Sym
      { symName = "present"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127873"
      }
  , Sym
      { symName = "pretzel"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129384"
      }
  , Sym
      { symName = "printer"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128424"
      }
  , Sym
      { symName = "prints.foot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128099"
      }
  , Sym
      { symName = "prints.paw"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128062"
      }
  , Sym
      { symName = "prohibited"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128683"
      }
  , Sym
      { symName = "projector"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128253"
      }
  , Sym
      { symName = "pumpkin.lantern"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127875"
      }
  , Sym
      { symName = "purse"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128091"
      }
  , Sym
      { symName = "quest"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10067"
      }
  , Sym
      { symName = "quest.white"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10068"
      }
  , Sym
      { symName = "rabbit"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128007"
      }
  , Sym
      { symName = "rabbit.face"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128048"
      }
  , Sym
      { symName = "raccoon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129437"
      }
  , Sym
      { symName = "radio"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128251"
      }
  , Sym
      { symName = "radioactive"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9762"
      }
  , Sym
      { symName = "railway"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128740"
      }
  , Sym
      { symName = "rainbow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127752"
      }
  , Sym
      { symName = "ram"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128015"
      }
  , Sym
      { symName = "rat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128000"
      }
  , Sym
      { symName = "razor"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129682"
      }
  , Sym
      { symName = "receipt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129534"
      }
  , Sym
      { symName = "recycling"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9851"
      }
  , Sym
      { symName = "reg"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\174"
      }
  , Sym
      { symName = "restroom"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128699"
      }
  , Sym
      { symName = "rhino"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129423"
      }
  , Sym
      { symName = "ribbon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127872"
      }
  , Sym
      { symName = "ribbon.remind"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127895"
      }
  , Sym
      { symName = "rice"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127834"
      }
  , Sym
      { symName = "rice.cracker"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127832"
      }
  , Sym
      { symName = "rice.ear"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127806"
      }
  , Sym
      { symName = "rice.onigiri"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127833"
      }
  , Sym
      { symName = "ring"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128141"
      }
  , Sym
      { symName = "ringbuoy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128735"
      }
  , Sym
      { symName = "robot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129302"
      }
  , Sym
      { symName = "rock"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129704"
      }
  , Sym
      { symName = "rocket"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128640"
      }
  , Sym
      { symName = "rollercoaster"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127906"
      }
  , Sym
      { symName = "rosette"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127989"
      }
  , Sym
      { symName = "rugby"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127945"
      }
  , Sym
      { symName = "ruler"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128207"
      }
  , Sym
      { symName = "ruler.triangle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128208"
      }
  , Sym
      { symName = "running"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127939"
      }
  , Sym
      { symName = "sa"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127490"
      }
  , Sym
      { symName = "safetypin"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129527"
      }
  , Sym
      { symName = "safetyvest"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129466"
      }
  , Sym
      { symName = "sake"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127862"
      }
  , Sym
      { symName = "salad"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129367"
      }
  , Sym
      { symName = "salt"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129474"
      }
  , Sym
      { symName = "sandwich"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129386"
      }
  , Sym
      { symName = "santa.man"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127877"
      }
  , Sym
      { symName = "santa.woman"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129334"
      }
  , Sym
      { symName = "satdish"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128225"
      }
  , Sym
      { symName = "satellite"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128752"
      }
  , Sym
      { symName = "saw"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129690"
      }
  , Sym
      { symName = "saxophone"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127927"
      }
  , Sym
      { symName = "scales"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9878"
      }
  , Sym
      { symName = "scarf"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129507"
      }
  , Sym
      { symName = "school"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127979"
      }
  , Sym
      { symName = "scissors"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9986"
      }
  , Sym
      { symName = "scooter"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128756"
      }
  , Sym
      { symName = "scooter.motor"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128757"
      }
  , Sym
      { symName = "scorpion"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129410"
      }
  , Sym
      { symName = "screwdriver"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129691"
      }
  , Sym
      { symName = "scroll"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128220"
      }
  , Sym
      { symName = "seal"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129453"
      }
  , Sym
      { symName = "seat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128186"
      }
  , Sym
      { symName = "seedling"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127793"
      }
  , Sym
      { symName = "shark"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129416"
      }
  , Sym
      { symName = "sheep"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128017"
      }
  , Sym
      { symName = "shell.spiral"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128026"
      }
  , Sym
      { symName = "shield"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128737"
      }
  , Sym
      { symName = "shin"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127544"
      }
  , Sym
      { symName = "ship"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128674"
      }
  , Sym
      { symName = "ship.cruise"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128755"
      }
  , Sym
      { symName = "ship.ferry"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9972"
      }
  , Sym
      { symName = "shirt.sports"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127933"
      }
  , Sym
      { symName = "shirt.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128085"
      }
  , Sym
      { symName = "shoe"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128094"
      }
  , Sym
      { symName = "shoe.ballet"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129648"
      }
  , Sym
      { symName = "shoe.flat"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129407"
      }
  , Sym
      { symName = "shoe.heel"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128096"
      }
  , Sym
      { symName = "shoe.hike"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129406"
      }
  , Sym
      { symName = "shoe.ice"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9976"
      }
  , Sym
      { symName = "shoe.roller"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128764"
      }
  , Sym
      { symName = "shoe.sandal.heel"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128097"
      }
  , Sym
      { symName = "shoe.ski"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127935"
      }
  , Sym
      { symName = "shoe.sneaker"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128095"
      }
  , Sym
      { symName = "shoe.tall"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128098"
      }
  , Sym
      { symName = "shoe.thong"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129652"
      }
  , Sym
      { symName = "shopping"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128717"
      }
  , Sym
      { symName = "shorts"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129651"
      }
  , Sym
      { symName = "shoshinsha"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128304"
      }
  , Sym
      { symName = "shovel"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129679"
      }
  , Sym
      { symName = "shower"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128703"
      }
  , Sym
      { symName = "shrimp"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129424"
      }
  , Sym
      { symName = "shrimp.fried"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127844"
      }
  , Sym
      { symName = "shrine"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9961"
      }
  , Sym
      { symName = "shuku"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\12951"
      }
  , Sym
      { symName = "sign.crossing"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128696"
      }
  , Sym
      { symName = "sign.stop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128721"
      }
  , Sym
      { symName = "silhouette"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128100"
      }
  , Sym
      { symName = "silhouette.double"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128101"
      }
  , Sym
      { symName = "silhouette.hug"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129730"
      }
  , Sym
      { symName = "silhouette.speak"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128483"
      }
  , Sym
      { symName = "siren"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128680"
      }
  , Sym
      { symName = "skateboard"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128761"
      }
  , Sym
      { symName = "skewer.dango"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127841"
      }
  , Sym
      { symName = "skewer.oden"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127842"
      }
  , Sym
      { symName = "skiing"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9975"
      }
  , Sym
      { symName = "skull"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128128"
      }
  , Sym
      { symName = "skull.bones"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9760"
      }
  , Sym
      { symName = "skunk"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129448"
      }
  , Sym
      { symName = "sled"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128759"
      }
  , Sym
      { symName = "slide"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128733"
      }
  , Sym
      { symName = "slider"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127898"
      }
  , Sym
      { symName = "sloth"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129445"
      }
  , Sym
      { symName = "slots"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127920"
      }
  , Sym
      { symName = "snail"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128012"
      }
  , Sym
      { symName = "snake"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128013"
      }
  , Sym
      { symName = "snowboarding"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127938"
      }
  , Sym
      { symName = "snowflake"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10052"
      }
  , Sym
      { symName = "snowman"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9924"
      }
  , Sym
      { symName = "snowman.snow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9731"
      }
  , Sym
      { symName = "soap"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129532"
      }
  , Sym
      { symName = "socks"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129510"
      }
  , Sym
      { symName = "softball"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129358"
      }
  , Sym
      { symName = "sos"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127384"
      }
  , Sym
      { symName = "soup"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127858"
      }
  , Sym
      { symName = "spaghetti"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127837"
      }
  , Sym
      { symName = "sparkle.box"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10055"
      }
  , Sym
      { symName = "sparkler"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127879"
      }
  , Sym
      { symName = "sparkles"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10024"
      }
  , Sym
      { symName = "speaker"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128264"
      }
  , Sym
      { symName = "speaker.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128263"
      }
  , Sym
      { symName = "speaker.wave"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128265"
      }
  , Sym
      { symName = "speaker.waves"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128266"
      }
  , Sym
      { symName = "spider"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128375"
      }
  , Sym
      { symName = "spiderweb"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128376"
      }
  , Sym
      { symName = "spinach"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129388"
      }
  , Sym
      { symName = "splatter"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129759"
      }
  , Sym
      { symName = "sponge"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129533"
      }
  , Sym
      { symName = "spoon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129348"
      }
  , Sym
      { symName = "square.black"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11035"
      }
  , Sym
      { symName = "square.black.tiny"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9642"
      }
  , Sym
      { symName = "square.black.small"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9726"
      }
  , Sym
      { symName = "square.black.medium"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9724"
      }
  , Sym
      { symName = "square.white"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11036"
      }
  , Sym
      { symName = "square.white.tiny"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9643"
      }
  , Sym
      { symName = "square.white.small"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9725"
      }
  , Sym
      { symName = "square.white.medium"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9723"
      }
  , Sym
      { symName = "square.blue"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128998"
      }
  , Sym
      { symName = "square.brown"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129003"
      }
  , Sym
      { symName = "square.green"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129001"
      }
  , Sym
      { symName = "square.orange"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128999"
      }
  , Sym
      { symName = "square.purple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129002"
      }
  , Sym
      { symName = "square.red"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128997"
      }
  , Sym
      { symName = "square.yellow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129000"
      }
  , Sym
      { symName = "squid"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129425"
      }
  , Sym
      { symName = "stadium"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127967"
      }
  , Sym
      { symName = "star"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\11088"
      }
  , Sym
      { symName = "star.arc"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128171"
      }
  , Sym
      { symName = "star.box"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\10036"
      }
  , Sym
      { symName = "star.glow"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127775"
      }
  , Sym
      { symName = "star.shoot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127776"
      }
  , Sym
      { symName = "stethoscope"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129658"
      }
  , Sym
      { symName = "store.big"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127980"
      }
  , Sym
      { symName = "store.small"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127978"
      }
  , Sym
      { symName = "strawberry"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127827"
      }
  , Sym
      { symName = "suit.club"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9827"
      }
  , Sym
      { symName = "suit.diamond"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9830"
      }
  , Sym
      { symName = "suit.heart"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9829"
      }
  , Sym
      { symName = "suit.spade"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9824"
      }
  , Sym
      { symName = "sun"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9728"
      }
  , Sym
      { symName = "sun.cloud"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127780"
      }
  , Sym
      { symName = "sun.face"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127774"
      }
  , Sym
      { symName = "sunrise"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127749"
      }
  , Sym
      { symName = "superhero"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129464"
      }
  , Sym
      { symName = "supervillain"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129465"
      }
  , Sym
      { symName = "surfing"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127940"
      }
  , Sym
      { symName = "sushi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127843"
      }
  , Sym
      { symName = "swan"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129442"
      }
  , Sym
      { symName = "swimming"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127946"
      }
  , Sym
      { symName = "swimsuit"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129649"
      }
  , Sym
      { symName = "swords"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9876"
      }
  , Sym
      { symName = "symbols"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128291"
      }
  , Sym
      { symName = "synagogue"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128333"
      }
  , Sym
      { symName = "syringe"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128137"
      }
  , Sym
      { symName = "taco"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127790"
      }
  , Sym
      { symName = "takeout"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129377"
      }
  , Sym
      { symName = "tamale"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129748"
      }
  , Sym
      { symName = "tanabata"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127883"
      }
  , Sym
      { symName = "tangerine"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127818"
      }
  , Sym
      { symName = "tap"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128688"
      }
  , Sym
      { symName = "tap.not"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128689"
      }
  , Sym
      { symName = "taxi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128661"
      }
  , Sym
      { symName = "taxi.front"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128662"
      }
  , Sym
      { symName = "teacup"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127861"
      }
  , Sym
      { symName = "teapot"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129750"
      }
  , Sym
      { symName = "teddy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129528"
      }
  , Sym
      { symName = "telescope"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128301"
      }
  , Sym
      { symName = "temple"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128725"
      }
  , Sym
      { symName = "ten"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128287"
      }
  , Sym
      { symName = "tengu"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128122"
      }
  , Sym
      { symName = "tennis"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127934"
      }
  , Sym
      { symName = "tent"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9978"
      }
  , Sym
      { symName = "testtube"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129514"
      }
  , Sym
      { symName = "thermometer"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127777"
      }
  , Sym
      { symName = "thread"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129525"
      }
  , Sym
      { symName = "thumb.up"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128077"
      }
  , Sym
      { symName = "thumb.down"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128078"
      }
  , Sym
      { symName = "ticket.event"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127903"
      }
  , Sym
      { symName = "ticket.travel"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127915"
      }
  , Sym
      { symName = "tiger"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128005"
      }
  , Sym
      { symName = "tiger.face"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128047"
      }
  , Sym
      { symName = "tm"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8482"
      }
  , Sym
      { symName = "toilet"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128701"
      }
  , Sym
      { symName = "toiletpaper"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129531"
      }
  , Sym
      { symName = "toku"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127568"
      }
  , Sym
      { symName = "tomato"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127813"
      }
  , Sym
      { symName = "tombstone"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129702"
      }
  , Sym
      { symName = "tongue"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128069"
      }
  , Sym
      { symName = "toolbox"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129520"
      }
  , Sym
      { symName = "tooth"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129463"
      }
  , Sym
      { symName = "toothbrush"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129701"
      }
  , Sym
      { symName = "tornado"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127786"
      }
  , Sym
      { symName = "tower.tokyo"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128508"
      }
  , Sym
      { symName = "trackball"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128434"
      }
  , Sym
      { symName = "tractor"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128668"
      }
  , Sym
      { symName = "trafficlight.v"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128678"
      }
  , Sym
      { symName = "trafficlight.h"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128677"
      }
  , Sym
      { symName = "train"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128646"
      }
  , Sym
      { symName = "train.car"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128643"
      }
  , Sym
      { symName = "train.light"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128648"
      }
  , Sym
      { symName = "train.metro"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128647"
      }
  , Sym
      { symName = "train.mono"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128669"
      }
  , Sym
      { symName = "train.mountain"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128670"
      }
  , Sym
      { symName = "train.speed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128644"
      }
  , Sym
      { symName = "train.speed.bullet"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128645"
      }
  , Sym
      { symName = "train.steam"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128642"
      }
  , Sym
      { symName = "train.stop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128649"
      }
  , Sym
      { symName = "train.suspend"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128671"
      }
  , Sym
      { symName = "train.tram"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128650"
      }
  , Sym
      { symName = "train.tram.car"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128651"
      }
  , Sym
      { symName = "transgender"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9895"
      }
  , Sym
      { symName = "tray.inbox"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128229"
      }
  , Sym
      { symName = "tray.mail"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128232"
      }
  , Sym
      { symName = "tray.outbox"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128228"
      }
  , Sym
      { symName = "treasure"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129678"
      }
  , Sym
      { symName = "tree.deciduous"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127795"
      }
  , Sym
      { symName = "tree.evergreen"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127794"
      }
  , Sym
      { symName = "tree.leafless"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129726"
      }
  , Sym
      { symName = "tree.palm"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127796"
      }
  , Sym
      { symName = "tree.xmas"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127876"
      }
  , Sym
      { symName = "triangle.r"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9654"
      }
  , Sym
      { symName = "triangle.l"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = Binary
      , symText = "\9664"
      }
  , Sym
      { symName = "triangle.t"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128316"
      }
  , Sym
      { symName = "triangle.b"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128317"
      }
  , Sym
      { symName = "triangle.t.red"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128314"
      }
  , Sym
      { symName = "triangle.b.red"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128315"
      }
  , Sym
      { symName = "trident"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128305"
      }
  , Sym
      { symName = "troll"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129484"
      }
  , Sym
      { symName = "trombone"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129674"
      }
  , Sym
      { symName = "trophy"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127942"
      }
  , Sym
      { symName = "truck"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128666"
      }
  , Sym
      { symName = "truck.trailer"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128667"
      }
  , Sym
      { symName = "trumpet"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127930"
      }
  , Sym
      { symName = "tsukimi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127889"
      }
  , Sym
      { symName = "turkey"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129411"
      }
  , Sym
      { symName = "turtle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128034"
      }
  , Sym
      { symName = "tv"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128250"
      }
  , Sym
      { symName = "ufo"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128760"
      }
  , Sym
      { symName = "umbrella.open"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9730"
      }
  , Sym
      { symName = "umbrella.closed"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127746"
      }
  , Sym
      { symName = "umbrella.rain"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9748"
      }
  , Sym
      { symName = "umbrella.sun"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9969"
      }
  , Sym
      { symName = "unicorn"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129412"
      }
  , Sym
      { symName = "unknown"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129459"
      }
  , Sym
      { symName = "up"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127385"
      }
  , Sym
      { symName = "urn"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9905"
      }
  , Sym
      { symName = "vampire"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129499"
      }
  , Sym
      { symName = "violin"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127931"
      }
  , Sym
      { symName = "volcano"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127755"
      }
  , Sym
      { symName = "volleyball"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127952"
      }
  , Sym
      { symName = "vs"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127386"
      }
  , Sym
      { symName = "waffle"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129479"
      }
  , Sym
      { symName = "wand"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129668"
      }
  , Sym
      { symName = "warning"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9888"
      }
  , Sym
      { symName = "watch"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\8986"
      }
  , Sym
      { symName = "watch.stop"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9201"
      }
  , Sym
      { symName = "watermelon"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127817"
      }
  , Sym
      { symName = "waterpolo"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129341"
      }
  , Sym
      { symName = "wave"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127754"
      }
  , Sym
      { symName = "wc"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128702"
      }
  , Sym
      { symName = "weightlifting"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127947"
      }
  , Sym
      { symName = "whale"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128011"
      }
  , Sym
      { symName = "whale.spout"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128051"
      }
  , Sym
      { symName = "wheel"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128734"
      }
  , Sym
      { symName = "wheelchair"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129469"
      }
  , Sym
      { symName = "wheelchair.box"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9855"
      }
  , Sym
      { symName = "wheelchair.motor"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129468"
      }
  , Sym
      { symName = "wind"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127788"
      }
  , Sym
      { symName = "windchime"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127888"
      }
  , Sym
      { symName = "window"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129695"
      }
  , Sym
      { symName = "wine"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127863"
      }
  , Sym
      { symName = "wing"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129725"
      }
  , Sym
      { symName = "wireless"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128732"
      }
  , Sym
      { symName = "wolf"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128058"
      }
  , Sym
      { symName = "woman"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128105"
      }
  , Sym
      { symName = "woman.box"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128698"
      }
  , Sym
      { symName = "woman.crown"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128120"
      }
  , Sym
      { symName = "woman.old"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128117"
      }
  , Sym
      { symName = "woman.pregnant"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129328"
      }
  , Sym
      { symName = "wood"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129717"
      }
  , Sym
      { symName = "worm"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129713"
      }
  , Sym
      { symName = "wrench"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128295"
      }
  , Sym
      { symName = "wrestling"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129340"
      }
  , Sym
      { symName = "xray"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129659"
      }
  , Sym
      { symName = "yarn"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129526"
      }
  , Sym
      { symName = "yo"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127546"
      }
  , Sym
      { symName = "yoyo"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129664"
      }
  , Sym
      { symName = "yubi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127535"
      }
  , Sym
      { symName = "yuryo"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\127542"
      }
  , Sym
      { symName = "zebra"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129427"
      }
  , Sym
      { symName = "zodiac.aquarius"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9810"
      }
  , Sym
      { symName = "zodiac.aries"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9800"
      }
  , Sym
      { symName = "zodiac.cancer"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9803"
      }
  , Sym
      { symName = "zodiac.capri"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9809"
      }
  , Sym
      { symName = "zodiac.gemini"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9802"
      }
  , Sym
      { symName = "zodiac.leo"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9804"
      }
  , Sym
      { symName = "zodiac.libra"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9806"
      }
  , Sym
      { symName = "zodiac.ophi"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9934"
      }
  , Sym
      { symName = "zodiac.pisces"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9811"
      }
  , Sym
      { symName = "zodiac.sagit"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9808"
      }
  , Sym
      { symName = "zodiac.scorpio"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9807"
      }
  , Sym
      { symName = "zodiac.taurus"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9801"
      }
  , Sym
      { symName = "zodiac.virgo"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\9805"
      }
  , Sym
      { symName = "zombie"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\129503"
      }
  , Sym
      { symName = "zzz"
      , symIsAccent = False
      , symDeprecation = Nothing
      , symMathClass = None
      , symText = "\128164"
      }
  ]


-- A list of pairs of math shorthands and symbol names.
mathSymbolShorthands :: [(Text, Text)]
mathSymbolShorthands =

  [ ( "..." , "\8230" )
  , ( "-" , "\8722" )
  , ( "..." , "\8230" )
  , ( "-" , "\8722" )
  , ( "*" , "\8727" )
  , ( "~" , "\8764" )
  , ( "!=" , "\8800" )
  , ( ":=" , "\8788" )
  , ( "::=" , "\10868" )
  , ( "=:" , "\8789" )
  , ( "<<" , "\8810" )
  , ( "<<<" , "\8920" )
  , ( ">>" , "\8811" )
  , ( ">>>" , "\8921" )
  , ( "<=" , "\8804" )
  , ( ">=" , "\8805" )
  , ( "->" , "\8594" )
  , ( "-->" , "\10230" )
  , ( "|->" , "\8614" )
  , ( ">->" , "\8611" )
  , ( "->>" , "\8608" )
  , ( "<-" , "\8592" )
  , ( "<--" , "\10229" )
  , ( "<-<" , "\8610" )
  , ( "<<-" , "\8606" )
  , ( "<->" , "\8596" )
  , ( "<-->" , "\10231" )
  , ( "~>" , "\8669" )
  , ( "~~>" , "\10239" )
  , ( "<~" , "\8668" )
  , ( "<~~" , "\11059" )
  , ( "=>" , "\8658" )
  , ( "|=>" , "\10503" )
  , ( "==>" , "\10233" )
  , ( "<==" , "\10232" )
  , ( "<=>" , "\8660" )
  , ( "<==>" , "\10234" )
  , ( "[|" , "\10214" )
  , ( "|]" , "\10215" )
  , ( "||" , "\8214" )
  ]



